All Classes Interface Summary Class Summary Enum Summary Exception Summary
| Class |
Description |
| AbstractConnectableAutomaton |
|
| AbstractDeviceAutomaton |
|
| BidirectionalConnectionAccessor<INPUT,OUTPUT> |
|
| BidirectionalConnectionAccessor.BidirectionalConnectionMutator<INPUT,OUTPUT> |
|
| BidirectionalConnectionAccessor.BidirectionalConnectionProperty<INPUT,OUTPUT> |
|
| BidirectionalConnectionComponent<INPUT,OUTPUT> |
|
| BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT> |
|
| BidirectionalConnectionOpenable<INPUT,OUTPUT> |
This mixin might be implemented by a component in order to provide opening
connection(s) facilities.
|
| BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT> |
|
| BidirectionalConnectionOpenableHandle<H,INPUT,OUTPUT> |
|
| BidirectionalConnectionOpenableHandle.BidirectionalConnectionOpenAutomatonHandle<H,INPUT,OUTPUT> |
|
| Ceasable |
This mixin might be implemented by a component in order to provide cease
facilities.
|
| Ceasable.CeaseAutomaton |
|
| Ceasable.CeaseBuilder<B extends Ceasable.CeaseBuilder<B>> |
To enable the Ceasable functionality to be invoked in a builder
chain.
|
| Ceasable.UncheckedCeasable |
See Ceasable without any checked exception being declared.
|
| CeasableHandle<H> |
The CeasableHandle interface defines those methods related to the
handle based cease life-cycle.
|
| CeasableHandle.CeaseAutomatonHandle<H> |
|
| CeaseException |
Thrown in case ceasing a component caused problems.
|
| CeaseException.CeaseRuntimeException |
|
| Closable |
This mixin might be implemented by a component in order to provide closing
connection(s) facilities.
|
| Closable.CloseAutomaton |
|
| Closable.CloseBuilder<B extends Closable.CloseBuilder<B>> |
To enable the Closable functionality to be invoked in a builder
chain.
|
| ClosableHandle<H> |
The ClosableHandle interface defines those methods related to the
handle based close life-cycle.
|
| ClosableHandle.CloseAutomatonHandle<H> |
|
| ClosedAccessor |
Provides an accessor for a closed property.
|
| ClosedAccessor.ClosedMutator |
Provides a mutator for a closed property.
|
| ClosedAccessor.ClosedProperty |
Provides a closed property.
|
| CloseException |
Thrown in case closing a component caused problems.
|
| CloseException.CloseRuntimeException |
|
| Component |
|
| ComponentException |
This exception is the base exception for the component package.
|
| ComponentRuntimeException |
This exception is the base runtime exception for the component package.
|
| ComponentUtility |
The Class ComponentUtility.
|
| CompositeComponent |
|
| CompositeComponent.ExtendedCompositeComponent<CTX,CON> |
|
| CompositeComponentHandle<H,REF> |
Similar to the CompositeComponent, the
CompositeComponentHandle provides all the defined handle based
functionality, implementing classes provide the means to invoke those methods
in case them are supported by the referenced components.
|
| CompositeComponentImpl<C extends Component> |
|
| CompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX,CON> |
|
| Configurable<CTX> |
|
| Configurable.ConfigureAutomaton<CTX> |
|
| Configurable.ConfigureBuilder<CTX,B extends Configurable.ConfigureBuilder<CTX,B>> |
To enable the Initializable functionality to be invoked in a
builder chain.
|
| ConfigurableComponent<CTX> |
|
| ConfigurableHandle<H,CTX> |
The ConfigurableHandle interface defines those methods related to the
handle based initialize/configure life-cycle.
|
| ConfigurableHandle.ConfigureAutomatonHandle<H,CTX> |
|
| ConfigurableLifecycleAutomatonImpl<CTX> |
|
| ConfigurableLifecycleComponent<CTX> |
|
| ConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX> |
|
| ConfigurableLifecycleComponentHandle<H,CTX> |
|
| ConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H,CTX> |
|
| ConfigureException |
Thrown in case initializing a component caused problems.
|
| ConfigureException.ConfigureRuntimeException |
Thrown in case initializing a component caused problems.
|
| ConnectableComponent |
Any Component which operates established connections may implement
the ConnectableComponent interface providing a minimal set of
functionality to work with connections; to test whether a connection is open
and to close an open connection.
|
| ConnectableComponent.ConnectableAutomaton |
|
| ConnectionAccessor<CON> |
|
| ConnectionAccessor.ConnectionMutator<CON> |
|
| ConnectionAccessor.ConnectionProperty<CON> |
|
| ConnectionAutomatonImpl<CON> |
|
| ConnectionComponent<CON> |
|
| ConnectionComponent.ConnectionAutomaton<CON> |
A system implementing the ConnectionComponent.ConnectionAutomaton interface supports
managing ConnectionComponent instances and takes care that the
open/close statuses are invoked in the correct order by throwing
according exceptions in case the open/close-cycle is invoked in the wrong
order.
|
| ConnectionComponent.ConnectionComponentBuilder<CON,B extends ConnectionComponent.ConnectionComponentBuilder<CON,B>> |
|
| ConnectionComponentHandle<H,CON> |
|
| ConnectionComponentHandle.ConnectionAutomatonHandle<H,CON> |
|
| ConnectionOpenable<CON> |
This mixin might be implemented by a component in order to provide opening
connection(s) facilities.
|
| ConnectionOpenable.ConnectionOpenAutomaton<CON> |
|
| ConnectionOpenable.ConnectionOpenBuilder<CON,B extends ConnectionOpenable.ConnectionOpenBuilder<CON,B>> |
To enable the Startable functionality to be invoked in a builder
chain.
|
| ConnectionOpenableHandle<H,CON> |
|
| ConnectionOpenableHandle.ConnectionOpenAutomatonHandle<H,CON> |
|
| ConnectionRequest |
An enumeration describing the connection requests.
|
| ConnectionStatus |
The Enum ConnectionStatus.
|
| ConnectionStatusAccessor |
|
| ConnectionStatusAccessor.ConnectionStatusMutator |
|
| ConnectionStatusAccessor.ConnectionStatusProperty |
|
| ConnectionStatusHandle<H> |
The Interface ConnectionStatusHandle.
|
| ContextAccessor<CTX> |
Provides an accessor for a context property for e.g. a service or a
component.
|
| ContextAccessor.ContextBuilder<CTX,B extends ContextAccessor.ContextBuilder<CTX,B>> |
Provides a builder method for a context property returning the builder
for applying multiple build operations.
|
| ContextAccessor.ContextMutator<CTX> |
Provides a mutator for a context property for e.g. a service or a
component.
|
| ContextAccessor.ContextProperty<CTX> |
Provides a context property for e.g. a service or a component.
|
| Decomposeable |
This mixin might be implemented by a component in order to provide
decomposition facilities.
|
| Decomposeable.DecomposeAutomaton |
|
| DecomposeableHandle<H> |
The DecomposeableHandle interface defines those methods related to
the handle based decompose life-cycle.
|
| DecomposeableHandle.DecomposeAutomatonHandle<H> |
|
| DecomposeException |
Thrown in case decomposing a component caused problems.
|
| DecomposeException.DecomposeRuntimeException |
|
| Destroyable |
This mixin might be implemented by a Component in order to provide
destroy facilities.
|
| Destroyable.DestroyAutomaton |
|
| DestroyableHandle<H> |
The DestroyableHandle interface defines those methods related to the
handle based destroy life-cycle.
|
| DestroyableHandle.DestroyAutomatonHandle<H> |
|
| DestroyException |
Thrown in case stopping a component caused problems.
|
| DestroyException.DestroyRuntimeException |
|
| Digester<J> |
A Digester provides the functionality to consume a job (which is
pushed from the outside) for further processing.
|
| DigesterComponent<J> |
|
| DigestException |
|
| DigestException.DigestRuntimeException |
|
| DisposableHandle<H> |
The DisposableHandle interface defines those methods related to the
handle based dispose life-cycle.
|
| DisposableHandle.DisposeAutomatonHandle<H> |
|
| DisposeAutomaton |
The DisposeAutomaton interface defines those methods related to the
dispose life-cycle.
|
| DisposeException |
Thrown in case disposing a component caused problems.
|
| DisposeException.DisposeRuntimeException |
|
| ExecutionStatus |
|
| Flushable |
This mixin might be implemented by a component in order to provide flush
facilities.
|
| Flushable.FlushBuilder<B extends Flushable.FlushBuilder<B>> |
The Interface FlushBuilder.
|
| FlushHandle<H> |
The FlushHandle interface defines those methods related to the handle
based flush operation.
|
| HandleAccessor<H> |
Provides an accessor for a handle property for e.g. key / handle pair.
|
| HandleAccessor.HandleMutator<H> |
Provides a mutator for a handle property for e.g. key / handle pair.
|
| HandleAccessor.HandleProperty<H> |
Provides a handle property for e.g. key / handle pair.
|
| HandleDirectory<H,REF> |
The handle directory enables listing of all known data managed by the
implementing component.
|
| HandleGenerator<H> |
Generates handles of the generic type.
|
| HandleGeneratorImpl |
Plain straight forward String instances generating
HandleGenerator basically being a plain good old
UniqueIdGenerator.
|
| HandleLookup<H,REF> |
Any system in this framework being able to work with handles provides an
implementation of the handle lookup interface.
|
| HandleTimeoutRuntimeException |
This exception is thrown in case a handle was provided which was unknown to
the invoked component.
|
| HealthChecker |
|
| IllegalHandleStateChangeRuntimeException |
This exception is thrown in case a handle was provided whose reference does
not support a given operation.
|
| Initializable |
This mixin might be implemented by a component in order to provide
initializing facilities.
|
| Initializable.InitializeAutomaton |
|
| Initializable.InitializeBuilder<B extends Initializable.InitializeBuilder<B>> |
To enable the Initializable functionality to be invoked in a
builder chain.
|
| Initializable.UncheckedInitializable |
|
| InitializableComponent |
|
| InitializableHandle<H> |
The InitializableHandle interface defines those methods related to
the handle based initialize life-cycle.
|
| InitializableHandle.InitializeAutomatonHandle<H> |
|
| InitializedAccessor |
Provides an accessor for a initialized property.
|
| InitializedAccessor.InitializedMutator |
Provides a mutator for a initialized property.
|
| InitializedAccessor.InitializedProperty |
Provides a initialized property.
|
| InitializedHandle<H> |
Provides access to the initialized handle reference.
|
| InitializeException |
Thrown in case initializing a component caused problems.
|
| InitializeException.InitializeRuntimeException |
Unchecked exception with the same semantics as the IOException.
|
| LifecycleAutomatonImpl |
|
| LifecycleAutomatonImpl.ManualLifecycleAutomatonImpl |
|
| LifecycleComponent |
|
| LifecycleComponent.LifecycleAutomaton |
A system implementing the LifecycleComponent.LifecycleAutomaton interface supports
managing LifecycleComponent instances and takes care that the
life-cycle stages are invoked in the correct order by throwing according
exceptions in case the life-cycle is invoked in the wrong order.
|
| LifecycleComponent.UncheckedLifecycleComponent |
Same as the LifecycleComponent though without the need to
try-catch any exceptions on the various life-cycle stages.
|
| LifecycleComponentHandle<H> |
|
| LifecycleComponentHandle.LifecycleAutomatonHandle<H> |
|
| LifecycleException |
This exception is the base lifecycle exception .
|
| LifecycleException.LifecycleRuntimeException |
This exception is the base lifecycle exception .
|
| LifecycleRequest |
An enumeration describing the lifecycle requests regarding a component..
|
| LifecycleRequestAccessor |
|
| LifecycleRequestAccessor.LifecycleRequestMutator |
|
| LifecycleRequestAccessor.LifecycleRequestProperty |
|
| LifecycleStatus |
The Enum LifecycleStatus.
|
| LifecycleStatusAccessor |
|
| LifecycleStatusAccessor.LifecycleStatusBuilder<B extends LifecycleStatusAccessor.LifecycleStatusBuilder<B>> |
Provides a builder method for a LifecycleStatus property
returning the builder for applying multiple build operations.
|
| LifecycleStatusAccessor.LifecycleStatusMutator |
|
| LifecycleStatusAccessor.LifecycleStatusProperty |
|
| LifecycleStatusHandle<H> |
The Interface LifecycleStatusHandle.
|
| LinkAutomatonImpl |
|
| LinkComponent |
A component implementing the LinkComponent interface supports
establishing a connection (not necessarily a network connection).
|
| LinkComponent.LinkAutomaton |
A system implementing the LinkComponent.LinkAutomaton interface supports
managing LinkComponent instances and takes care that the
open/close statuses are invoked in the correct order by throwing
according exceptions in case the open/close-cycle is invoked in the wrong
order.
|
| LinkComponent.LinkComponentBuilder<B extends LinkComponent.LinkComponentBuilder<B>> |
Similar to the LinkComponent with additional according builder
methods.
|
| LinkComponentHandle<H> |
|
| LinkComponentHandle.LinkAutomatonHandle<H> |
|
| Openable |
This mixin might be implemented by a component in order to provide opening
connection(s) facilities.
|
| Openable.OpenAutomaton |
The Openable.OpenAutomaton interface defines those methods related to the
opening of connection(s) life-cycle.
|
| Openable.OpenBuilder<B extends Openable.OpenBuilder<B>> |
To enable the Startable functionality to be invoked in a builder
chain.
|
| OpenableHandle<H> |
The OpenableHandle interface defines those methods related to the
handle based open/connect life-cycle.
|
| OpenableHandle.OpenAutomatonHandle<H> |
|
| OpenedAccessor |
Provides an accessor for a opened property.
|
| OpenedAccessor.OpenedMutator |
Provides a mutator for a opened property.
|
| OpenedAccessor.OpenedProperty |
Provides a opened property.
|
| OpenedHandle<H> |
Provides access to the opened (connected) handle reference.
|
| Pausable |
This mixin might be implemented by a component in order to provide pause
facilities.
|
| Pausable.PauseAutomaton |
|
| Pausable.PauseBuilder<B extends Pausable.PauseBuilder<B>> |
To enable the Pausable functionality to be invoked in a builder
chain.
|
| Pausable.UncheckedPausable |
See Pausable without any checked exception being declared.
|
| PausableHandle<H> |
The PausableHandle interface defines those methods related to the
handle based pause life-cycle.
|
| PausableHandle.PauseAutomatonHandle<H> |
|
| PauseException |
Thrown in case pausing a component caused problems.
|
| PauseException.PauseRuntimeException |
|
| ProgressAccessor |
Provides an accessor for a progress property.
|
| ProgressAccessor.ProgressMutator |
Provides a mutator for a progress property.
|
| ProgressAccessor.ProgressProperty |
Provides a progress property.
|
| ProgressHandle<H> |
Whenever a handle is associated with a progress, then a component providing
such handles should implement this interface.
|
| Reloadable |
This mixin might be implemented by a component in order to provide reload
facilities.
|
| Reloadable.ReloadBuilder<B extends Reloadable.ReloadBuilder<B>> |
The Interface ReloadBuilder.
|
| ReloadHandle<H> |
The ReloadHandle interface defines those methods related to the
handle based reload operation.
|
| Resetable |
This mixin might be implemented by a component in order to provide reset
facilities.
|
| ResetException |
Thrown in case resetting a component caused problems.
|
| ResetException.ResetRuntimeException |
|
| ResetHandle<H> |
The ResetHandle interface defines those methods related to the handle
based reset operation.
|
| Resumable |
This mixin might be implemented by a component in order to provide resume
facilities.
|
| Resumable.ResumeAutomaton |
|
| Resumable.ResumeBuilder<B extends Resumable.ResumeBuilder<B>> |
To enable the Resumable functionality to be invoked in a builder
chain.
|
| Resumable.UncheckedResumable |
See Resumable without any checked exception being declared.
|
| ResumableHandle<H> |
The ResumableHandle interface defines those methods related to the
handle based resume life-cycle.
|
| ResumableHandle.ResumeAutomatonHandle<H> |
|
| ResumeException |
Thrown in case resuming a component caused problems.
|
| ResumeException.ResumeRuntimeException |
|
| RunningAccessor |
Provides an accessor for a running property.
|
| RunningAccessor.RunningMutator |
Provides a mutator for a running property.
|
| RunningAccessor.RunningProperty |
Provides a running property.
|
| RunningHandle<H> |
Provides access to the running handle reference.
|
| Startable |
This mixin might be implemented by a component in order to provide start
facilities.
|
| Startable.StartAutomaton |
|
| Startable.StartBuilder<B extends Startable.StartBuilder<B>> |
To enable the Startable functionality to be invoked in a builder
chain.
|
| Startable.UncheckedStartable |
See Startable without any checked exception being declared.
|
| StartableHandle<H> |
The StartableHandle interface defines those methods related to the
handle based start life-cycle.
|
| StartableHandle.StartAutomatonHandle<H> |
|
| StartException |
Thrown in case starting a component caused problems.
|
| StartException.StartRuntimeException |
|
| StopException |
Thrown in case stopping a component caused problems.
|
| StopException.StopRuntimeException |
Unchecked exception with the same semantics as the StopException.
|
| Stoppable |
This mixin might be implemented by a component in order to provide stop
facilities.
|
| Stoppable.StopAutomaton |
|
| Stoppable.StopBuilder<B extends Stoppable.StopBuilder<B>> |
To enable the Stoppable functionality to be invoked in a builder
chain.
|
| Stoppable.UncheckedStoppable |
See Stoppable without any checked exception being declared.
|
| StoppableHandle<H> |
The StoppableHandle interface defines those methods related to the
handle based stop life-cycle.
|
| StoppableHandle.StopAutomatonHandle<H> |
|
| UnknownHandleRuntimeException |
This exception is thrown in case a handle was provided which was unknown to
the invoked component.
|
| UnsupportedHandleOperationRuntimeException |
This exception is thrown in case a handle was provided whose reference does
not support a given operation.
|