Class AbstractComponentComposite.ExtendedCompositeComponentImpl<C extends Component, CTX, CON>
java.lang.Object
org.refcodes.component.AbstractComponentComposite<C>
org.refcodes.component.AbstractComponentComposite.ExtendedCompositeComponentImpl<C,CTX,CON>
- Type Parameters:
C- The type of theComponentsupported by theAbstractComponentComposite.ExtendedCompositeComponentImpl.CTX- the generic typeCON- the generic type
- All Implemented Interfaces:
Flushable, Closable, ComponentComposite, ComponentComposite.ExtendedComponentComposite<CTX,CON>, Configurable<CTX>, ConfigurableLifecycleComponent<CTX>, ConnectionComponent<CON>, ConnectionOpenable<CON>, Decomposable, Destroyable, Flushable, Initializable, LifecycleComponent, LinkComponent, Openable, Pausable, Resumable, Startable, Stoppable, Disposable, Resetable
- Enclosing class:
AbstractComponentComposite<C extends Component>
public static class AbstractComponentComposite.ExtendedCompositeComponentImpl<C extends Component, CTX, CON>
extends AbstractComponentComposite<C>
implements ComponentComposite.ExtendedComponentComposite<CTX,CON>
The
AbstractComponentComposite.ExtendedCompositeComponentImpl is an implementation of the
ComponentComposite.ExtendedComponentComposite. To make sure that the state change
requests you require are supported by the managed Component
instances, specify the according type C as generic type
argument.-
Nested Class Summary
Nested classes/interfaces inherited from class AbstractComponentComposite
AbstractComponentComposite.ExtendedCompositeComponentImpl<C,CTX, CON> Nested classes/interfaces inherited from interface Closable
Closable.CloseAutomaton, Closable.CloseBuilder<B>Nested classes/interfaces inherited from interface ComponentComposite
ComponentComposite.ExtendedComponentComposite<CTX,CON> Nested classes/interfaces inherited from interface Configurable
Configurable.ConfigureAutomaton<CTX>, Configurable.ConfigureBuilder<CTX,B> Nested classes/interfaces inherited from interface ConfigurableLifecycleComponent
ConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX>Nested classes/interfaces inherited from interface ConnectionComponent
ConnectionComponent.ConnectionAutomaton<CON>, ConnectionComponent.ConnectionComponentBuilder<CON,B> Nested classes/interfaces inherited from interface ConnectionOpenable
ConnectionOpenable.ConnectionOpenAutomaton<CON>, ConnectionOpenable.ConnectionOpenBuilder<CON,B> Nested classes/interfaces inherited from interface Decomposable
Decomposable.DecomposeAutomatonNested classes/interfaces inherited from interface Destroyable
Destroyable.DestroyAutomatonNested classes/interfaces inherited from interface Flushable
Flushable.FlushBuilder<B>Nested classes/interfaces inherited from interface Initializable
Initializable.InitializeAutomaton, Initializable.InitializeBuilder<B>, Initializable.UncheckedInitializableNested classes/interfaces inherited from interface LifecycleComponent
LifecycleComponent.LifecycleAutomaton, LifecycleComponent.UncheckedLifecycleComponentNested classes/interfaces inherited from interface LinkComponent
LinkComponent.LinkAutomaton, LinkComponent.LinkComponentBuilder<B>Nested classes/interfaces inherited from interface Openable
Openable.OpenAutomaton, Openable.OpenBuilder<B>Nested classes/interfaces inherited from interface Pausable
Pausable.PauseAutomaton, Pausable.PauseBuilder<B>, Pausable.UncheckedPausableNested classes/interfaces inherited from interface Resumable
Resumable.ResumeAutomaton, Resumable.ResumeBuilder<B>, Resumable.UncheckedResumableNested classes/interfaces inherited from interface Startable
Startable.StartAutomaton, Startable.StartBuilder<B>, Startable.UncheckedStartableNested classes/interfaces inherited from interface Stoppable
Stoppable.StopAutomaton, Stoppable.StopBuilder<B>, Stoppable.UncheckedStoppable -
Constructor Summary
ConstructorsConstructorDescriptionExtendedCompositeComponentImpl(C... aComponents) Instantiates the classAbstractComponentComposite.ExtendedCompositeComponentImpl.ExtendedCompositeComponentImpl(Collection<C> aComponents) Instantiates the classAbstractComponentComposite.ExtendedCompositeComponentImpl.ExtendedCompositeComponentImpl(ExecutionStrategy aStrategy, C... aComponents) Instantiates the classAbstractComponentComposite.ExtendedCompositeComponentImpl.ExtendedCompositeComponentImpl(ExecutionStrategy aStrategy, Collection<C> aComponents) Instantiates the classAbstractComponentComposite.ExtendedCompositeComponentImpl. -
Method Summary
Modifier and TypeMethodDescriptionvoidinitialize(CTX aContext) Initializes and configures the component.voidOpens the component with the given connection.Methods inherited from class AbstractComponentComposite
close, decompose, destroy, dispose, flush, getComponents, getExecutionStrategy, initialize, open, pause, reset, resume, start, stopMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface Configurable
initializeUncheckedMethods inherited from interface ConnectionOpenable
openUncheckedMethods inherited from interface Decomposable
decomposeMethods inherited from interface Destroyable
destroyMethods inherited from interface Disposable
disposeMethods inherited from interface Flushable
flush, flushUnchecked, isFlushableMethods inherited from interface Initializable
initialize, initializeUncheckedMethods inherited from interface Openable
open, openUncheckedMethods inherited from interface Pausable
pause, pauseUncheckedMethods inherited from interface Resumable
resume, resumeUncheckedMethods inherited from interface Startable
start, startUncheckedMethods inherited from interface Stoppable
stop, stopUnchecked
-
Constructor Details
-
ExtendedCompositeComponentImpl
Instantiates the classAbstractComponentComposite.ExtendedCompositeComponentImpl.- See Also:
-
ExtendedCompositeComponentImpl
Instantiates the classAbstractComponentComposite.ExtendedCompositeComponentImpl.- See Also:
-
ExtendedCompositeComponentImpl
Instantiates the classAbstractComponentComposite.ExtendedCompositeComponentImpl.- See Also:
-
ExtendedCompositeComponentImpl
Instantiates the classAbstractComponentComposite.ExtendedCompositeComponentImpl.- See Also:
-
-
Method Details
-
initialize
Initializes and configures the component.- Specified by:
initializein interfaceConfigurable<C extends Component>- Parameters:
aContext- The context to be passed to the implementing instance.- Throws:
ConfigureException
-
open
Opens the component with the given connection.- Specified by:
openin interfaceConnectionOpenable<C extends Component>- Parameters:
aConnection- The connection used for opening the connection.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-