Interface BidirectionalConnectionAccessor.BidirectionalConnectionMutator<INPUT,​OUTPUT>

Type Parameters:
INPUT - The type of the input connection property.
OUTPUT - The type of the output connection property.
All Known Subinterfaces:
BidirectionalConnectionAccessor.BidirectionalConnectionProperty<INPUT,​OUTPUT>
Enclosing interface:
BidirectionalConnectionAccessor<INPUT,​OUTPUT>

public static interface BidirectionalConnectionAccessor.BidirectionalConnectionMutator<INPUT,​OUTPUT>
Provides a mutator for a connection property for e.g. an InputStream or an OutputStream.
  • Method Summary

    Modifier and Type Method Description
    void setInputConnection​(INPUT aInputConnection)
    Sets the input connection for the connection property.
    void setOutputConnection​(OUTPUT aOutputConnection)
    Sets the output connection for the connection property.
  • Method Details

    • setInputConnection

      void setInputConnection​(INPUT aInputConnection)
      Sets the input connection for the connection property.
      Parameters:
      aInputConnection - The input connection to be stored by the connection property.
    • setOutputConnection

      void setOutputConnection​(OUTPUT aOutputConnection)
      Sets the output connection for the connection property.
      Parameters:
      aOutputConnection - The output connection to be stored by the connection property.