Interface BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>
- Type Parameters:
INPUT- The type of the input connection to be used.OUTPUT- The type of the output connection to be used.
- All Superinterfaces:
BidirectionalConnectionComponent<INPUT,OUTPUT>, BidirectionalConnectionOpenable<INPUT, OUTPUT>, BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT, OUTPUT>, Closable, Closable.CloseAutomaton, ClosedAccessor, ConnectionStatusAccessor, OpenedAccessor
- Enclosing interface:
BidirectionalConnectionComponent<INPUT,OUTPUT>
public static interface BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>
extends BidirectionalConnectionComponent<INPUT,OUTPUT>, BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT>, Closable.CloseAutomaton, ConnectionStatusAccessor
A system implementing the
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton
interface supports managing BidirectionalConnectionComponent
instances and takes care that the open/close statuses are invoked in the
correct order by throwing according exceptions in case the
open/close-cycle is invoked in the wrong order. A
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton may be used to wrap a
BidirectionalConnectionComponent by a
ConnectionComponentHandle.ConnectionAutomatonHandle for managing
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton instances. The
BidirectionalConnectionComponent contains the business-logic
where as the ConnectionComponentHandle.ConnectionAutomatonHandle provides the frame for
managing this business-logic. The
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton takes care of the correct
open/close-cycle applied on a BidirectionalConnectionComponent.-
Nested Class Summary
Nested classes/interfaces inherited from interface BidirectionalConnectionComponent
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT> Nested classes/interfaces inherited from interface BidirectionalConnectionOpenable
BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT> Nested classes/interfaces inherited from interface Closable
Closable.CloseAutomaton, Closable.CloseBuilder<B>Nested classes/interfaces inherited from interface ClosedAccessor
ClosedAccessor.ClosedMutator, ClosedAccessor.ClosedPropertyNested classes/interfaces inherited from interface ConnectionStatusAccessor
ConnectionStatusAccessor.ConnectionStatusMutator, ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface OpenedAccessor
OpenedAccessor.OpenedMutator, OpenedAccessor.OpenedProperty -
Method Summary
Methods inherited from interface BidirectionalConnectionOpenable
openMethods inherited from interface BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton
isOpenableMethods inherited from interface Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface Closable.CloseAutomaton
isClosableMethods inherited from interface ClosedAccessor
isClosedMethods inherited from interface ConnectionStatusAccessor
getConnectionStatus, isOpened