Interface BidirectionalConnectionOpenable<INPUT,OUTPUT>

Type Parameters:
INPUT - The type of the input connection to be used.
OUTPUT - The type of the output connection to be used.
All Known Subinterfaces:
BidirectionalConnectionComponent<INPUT,OUTPUT>, BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>, BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT>

public interface BidirectionalConnectionOpenable<INPUT,OUTPUT>
This mixin might be implemented by a component in order to provide opening connection(s) facilities. The semantics of this interface is very similar to that of the Configurable interface. To clarify the context regarding connections, the BidirectionalConnectionOpenable interface has been introduced.

In case a no connection is to be provided to the open(Object, Object) method (as it may have been passed via the constructor), you may use the Openable interface with its Openable.open() method, which does not require any arguments specifying a connection.