Interface BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT>

Type Parameters:
INPUT - The type of the input connection to be used.
OUTPUT - The type of the output connection to be used.
All Superinterfaces:
BidirectionalConnectionOpenable<INPUT,OUTPUT>, OpenedAccessor
All Known Subinterfaces:
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>
Enclosing interface:
BidirectionalConnectionOpenable<INPUT,OUTPUT>

public static interface BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT> extends BidirectionalConnectionOpenable<INPUT,OUTPUT>, OpenedAccessor
The BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton interface defines those methods related to the opening of connection(s) life-cycle. The semantics of this interface is very similar to that of the Configurable.ConfigureAutomaton interface. To clarify the context regarding connections, the BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton interface has been introduced.