Interface BidirectionalConnectionOpenableHandle.BidirectionalConnectionOpenAutomatonHandle<H,​INPUT,​OUTPUT>

Type Parameters:
H - The type of the handle.
INPUT - The type of the input connection to be used.
OUTPUT - The type of the output connection to be used.
All Superinterfaces:
BidirectionalConnectionOpenableHandle<H,​INPUT,​OUTPUT>, OpenedHandle<H>
Enclosing interface:
BidirectionalConnectionOpenableHandle<H,​INPUT,​OUTPUT>

public static interface BidirectionalConnectionOpenableHandle.BidirectionalConnectionOpenAutomatonHandle<H,​INPUT,​OUTPUT>
extends BidirectionalConnectionOpenableHandle<H,​INPUT,​OUTPUT>, OpenedHandle<H>
The BidirectionalConnectionOpenableHandle.BidirectionalConnectionOpenAutomatonHandle interface defines those methods related to the handle based open/connect life-cycle. The handle reference requires the ConnectionOpenable.ConnectionOpenAutomaton interface to be implemented.