Interface Ceasable.CeaseBuilder<B extends Ceasable.CeaseBuilder<B>>
-
Method Summary
Modifier and TypeMethodDescriptionBuilder method for theCeasable.cease()method.default BCeases the component by callingwithCease()without you to require catching anCeaseException.
-
Method Details
-
withCease
Builder method for theCeasable.cease()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
CeaseException- Thrown in case ceasing fails.
-
withCeaseUnchecked
Ceases the component by callingwithCease()without you to require catching anCeaseException.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
CeaseException.CeaseRuntimeException- encapsulates the aCause and is thrown upon encountering aCeaseExceptionexception
-