Interface CeasableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CeasableHandle.CeaseAutomatonHandle<H>

public interface CeasableHandle<H>
The CeasableHandle interface defines those methods related to the handle based cease life-cycle.

The handle reference requires the Ceasable interface to be implemented.