Interface CeasableHandle.CeaseAutomatonHandle<H>

Type Parameters:
H - The type of the handle.
All Superinterfaces:
CeasableHandle<H>
Enclosing interface:
CeasableHandle<H>

public static interface CeasableHandle.CeaseAutomatonHandle<H>
extends CeasableHandle<H>
The CeasableHandle.CeaseAutomatonHandle interface defines those methods related to the handle based cease life-cycle. The handle reference requires the Ceasable.CeaseAutomaton interface to be implemented.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.component.CeasableHandle

    CeasableHandle.CeaseAutomatonHandle<H>
  • Method Summary

    Modifier and Type Method Description
    boolean hasCeaseAutomaton​(H aHandle)
    Determines whether the handle reference is ceasable by implementing the Ceasable.CeaseAutomaton interface.
    boolean isCeasable​(H aHandle)
    Determines whether the component identified by the given handle may get ceased.
    boolean isCeased​(H aHandle)
    Determines whether the component identified by the given handle is ceased.

    Methods inherited from interface org.refcodes.component.CeasableHandle

    cease, hasCeasable