Module org.refcodes.component
Package org.refcodes.component
Interface Closable.CloseBuilder<B extends Closable.CloseBuilder<B>>
- Type Parameters:
B- The instance to be returned on which to apply succeeding builder operations.
- All Known Subinterfaces:
ConnectionComponent.ConnectionComponentBuilder<CON,B>,LinkComponent.LinkComponentBuilder<B>
- Enclosing interface:
- Closable
public static interface Closable.CloseBuilder<B extends Closable.CloseBuilder<B>>
To enable the
Closable functionality to be invoked in a builder
chain.-
Method Summary
Modifier and Type Method Description BwithClose()Builder method for theClosable.close()method.BwithCloseIn(int aCloseInMillis)Builder method for theClosable.closeIn( int )method.BwithCloseQuietly()Builder method for theClosable.closeQuietly()method.default BwithCloseUnchecked()Closes the component by callingwithClose()without you to require catching anIOException.
-
Method Details
-
withClose
Builder method for theClosable.close()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
IOException- in case closing or pre-closing (flushing) fails.
-
withCloseQuietly
B withCloseQuietly()Builder method for theClosable.closeQuietly()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
-
withCloseIn
Builder method for theClosable.closeIn( int )method.- Parameters:
aCloseInMillis- The time in milliseconds to pass tillClosable.close()is called.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
-
withCloseUnchecked
Closes the component by callingwithClose()without you to require catching anIOException.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
org.refcodes.exception.IORuntimeException- encapsulates the cause and is thrown upon encountering aIOExceptionexception
-