Interface ClosableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
ClosableHandle.CloseAutomatonHandle<H>, ConnectionComponentHandle<H,CON>, ConnectionComponentHandle.ConnectionAutomatonHandle<H,CON>, LinkComponentHandle<H>, LinkComponentHandle.LinkAutomatonHandle<H>

public interface ClosableHandle<H>
The ClosableHandle interface defines those methods related to the handle based close life-cycle.

The handle reference requires the Closable interface to be implemented.