Class ComponentException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.component.ComponentException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap
- Direct Known Subclasses:
CeaseException, CeaseException.CeaseRuntimeException, CloseException, CloseException.CloseRuntimeException, ComponentException.AbstractComponentHandleException, DecomposeException, DigestException, DisposeException, LifecycleException, ResetException, ResetException.ResetRuntimeException
This exception is the base runtime exception for the component package.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionprotected static classThis exception is the base exception for handle related runtime exceptions.Nested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionComponentException(String aMessage) Instantiates the classComponentException.ComponentException(String aMessage, String aErrorCode) Instantiates the classComponentException.ComponentException(String aMessage, Throwable aCause) Instantiates the classComponentException.ComponentException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classComponentException.ComponentException(Throwable aCause) Instantiates the classComponentException.ComponentException(Throwable aCause, String aErrorCode) Instantiates the classComponentException. -
Method Summary
Methods inherited from class AbstractRuntimeException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
ComponentException
Instantiates the classComponentException.- See Also:
-
ComponentException
Instantiates the classComponentException.- See Also:
-
ComponentException
Instantiates the classComponentException.- See Also:
-
ComponentException
-
ComponentException
Instantiates the classComponentException.- See Also:
-
ComponentException
-