Interface ComponentHandleComposite<H,REF>
- Type Parameters:
H- The type of the handles.REF- The type of the objects to which the handles reference to.
- All Superinterfaces:
DestroyableHandle<H>, DestroyableHandle.DestroyAutomatonHandle<H>, FlushHandle<H>, HandleLookup<H,REF>, InitializableHandle<H>, InitializableHandle.InitializeAutomatonHandle<H>, InitializedHandle<H>, LifecycleComponentHandle<H>, LifecycleComponentHandle.LifecycleAutomatonHandle<H>, LifecycleStatusHandle<H>, PausableHandle<H>, PausableHandle.PauseAutomatonHandle<H>, ProgressHandle<H>, ResetHandle<H>, ResumableHandle<H>, ResumableHandle.ResumeAutomatonHandle<H>, RunningHandle<H>, StartableHandle<H>, StartableHandle.StartAutomatonHandle<H>, StoppableHandle<H>, StoppableHandle.StopAutomatonHandle<H>
public interface ComponentHandleComposite<H,REF>
extends HandleLookup<H,REF>, LifecycleComponentHandle.LifecycleAutomatonHandle<H>, ProgressHandle<H>, ResetHandle<H>, FlushHandle<H>
Similar to the
ComponentComposite, the
ComponentHandleComposite provides all the defined handle based
functionality, implementing classes provide the means to invoke those methods
in case them are supported by the referenced components.-
Nested Class Summary
Nested classes/interfaces inherited from interface DestroyableHandle
DestroyableHandle.DestroyAutomatonHandle<H>Nested classes/interfaces inherited from interface InitializableHandle
InitializableHandle.InitializeAutomatonHandle<H>Nested classes/interfaces inherited from interface LifecycleComponentHandle
LifecycleComponentHandle.LifecycleAutomatonHandle<H>Nested classes/interfaces inherited from interface PausableHandle
PausableHandle.PauseAutomatonHandle<H>Nested classes/interfaces inherited from interface ResumableHandle
ResumableHandle.ResumeAutomatonHandle<H>Nested classes/interfaces inherited from interface StartableHandle
StartableHandle.StartAutomatonHandle<H>Nested classes/interfaces inherited from interface StoppableHandle
StoppableHandle.StopAutomatonHandle<H> -
Method Summary
Methods inherited from interface DestroyableHandle
destroy, hasDestroyableMethods inherited from interface DestroyableHandle.DestroyAutomatonHandle
hasDestroyAutomaton, isDestroyable, isDestroyedMethods inherited from interface FlushHandle
flush, flushUnchecked, hasFlushMethods inherited from interface HandleLookup
hasHandle, lookupHandle, removeHandleMethods inherited from interface InitializableHandle
hasInitalizable, initialize, initializeUncheckedMethods inherited from interface InitializableHandle.InitializeAutomatonHandle
hasInitializeAutomaton, isInitalizableMethods inherited from interface InitializedHandle
isInitzializedMethods inherited from interface LifecycleStatusHandle
getLifecycleStatus, hasLifecycleStatusMethods inherited from interface PausableHandle
hasPausable, pause, pauseUncheckedMethods inherited from interface PausableHandle.PauseAutomatonHandle
hasPauseAutomaton, isPausable, isPausedMethods inherited from interface ProgressHandle
getProgress, hasProgressMethods inherited from interface ResetHandle
hasReset, resetMethods inherited from interface ResumableHandle
hasResumable, resume, resumeUncheckedMethods inherited from interface ResumableHandle.ResumeAutomatonHandle
hasResumeAutomaton, isResumableMethods inherited from interface RunningHandle
isRunningMethods inherited from interface StartableHandle
hasStartable, start, startUncheckedMethods inherited from interface StartableHandle.StartAutomatonHandle
hasStartAutomaton, isStartableMethods inherited from interface StoppableHandle
hasStoppable, stop, stopUncheckedMethods inherited from interface StoppableHandle.StopAutomatonHandle
hasStopAutomaton, isStoppable, isStopped