Interface CompositeComponentHandle<H,​REF>

Type Parameters:
H - The type of the handles.
REF - The type of the objects to which the handles reference to.
All Superinterfaces:
DestroyableHandle<H>, DestroyableHandle.DestroyAutomatonHandle<H>, FlushHandle<H>, HandleLookup<H,​REF>, InitializableHandle<H>, InitializableHandle.InitializeAutomatonHandle<H>, InitializedHandle<H>, LifeCycleComponentHandle<H>, LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>, LifeCycleStatusHandle<H>, PausableHandle<H>, PausableHandle.PauseAutomatonHandle<H>, ProgressHandle<H>, ResetHandle<H>, ResumableHandle<H>, ResumableHandle.ResumeAutomatonHandle<H>, RunningHandle<H>, StartableHandle<H>, StartableHandle.StartAutomatonHandle<H>, StoppableHandle<H>, StoppableHandle.StopAutomatonHandle<H>

public interface CompositeComponentHandle<H,​REF>
extends HandleLookup<H,​REF>, LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>, ProgressHandle<H>, ResetHandle<H>, FlushHandle<H>
Similar to the CompositeComponent, the CompositeComponentHandle provides all the defined handle based functionality, implementing classes provide the means to invoke those methods in case them are supported by the referenced components.