Interface Configurable<CTX>

Type Parameters:
CTX - the context used to initialize the implementing instance.
All Known Subinterfaces:
ComponentComposite.ExtendedComponentComposite<CTX,CON>, Configurable.ConfigureAutomaton<CTX>, ConfigurableComponent<CTX>, ConfigurableLifecycleComponent<CTX>, ConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX>
All Known Implementing Classes:
AbstractComponentComposite.ExtendedCompositeComponentImpl, ConfigurableLifecycleAutomatonImpl

public interface Configurable<CTX>
This mixin might be implemented by a component in order to provide initialize facilities wit a configuration provided via initialize(Object).

In case a no context is to be provided to the initialize(Object) method (as it may have been passed via the constructor), you may use the Initializable interface with its Initializable.initialize() method, which does not require any arguments specifying a context.

  • Method Details

    • initialize

      void initialize(CTX aContext) throws InitializeException
      Initializes and configures the component.
      Parameters:
      aContext - The context to be passed to the implementing instance.
      Throws:
      InitializeException - Thrown in case initializing fails.