Interface Configurable.ConfigureBuilder<CTX,​B extends Configurable.ConfigureBuilder<CTX,​B>>

Type Parameters:
CTX - the context used to initialize the implementing instance.
B - The instance to be returned on which to apply succeeding builder operations.
Enclosing interface:
Configurable<CTX>

public static interface Configurable.ConfigureBuilder<CTX,​B extends Configurable.ConfigureBuilder<CTX,​B>>
To enable the Initializable functionality to be invoked in a builder chain.
  • Method Details

    • withInitialize

      B withInitialize​(CTX aContext) throws ConfigureException
      Builder method for the Configurable.initialize(Object) method.
      Parameters:
      aContext - The context to be passed to the implementing instance.
      Returns:
      The instance to be returned on which to apply succeeding builder operations.
      Throws:
      ConfigureException - Thrown in case initializing fails.
    • withInitializeUnchecked

      default B withInitializeUnchecked​(CTX aContext)
      Initializes the component by calling withInitialize(Object) without you to require catching an ConfigureException.
      Parameters:
      aContext - The context to be passed to the implementing instance.
      Returns:
      The instance to be returned on which to apply succeeding builder operations.
      Throws:
      org.refcodes.exception.HiddenException - encapsulates the cause and is thrown upon encountering a ConfigureException exception