Interface ConfigurableHandle<H,​CTX>

Type Parameters:
H - The type of the handle.
CTX - The context used to initialize the referenced instance.
All Known Subinterfaces:
ConfigurableHandle.ConfigureAutomatonHandle<H,​CTX>, ConfigurableLifeCycleComponentHandle<H,​CTX>, ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,​CTX>

public interface ConfigurableHandle<H,​CTX>
The ConfigurableHandle interface defines those methods related to the handle based initialize/configure life-cycle.

The handle reference requires the Configurable interface to be implemented.