Interface ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,​CTX>

Type Parameters:
H - The type of the handle.
CTX - the context used to initialize the referenced instance.
All Superinterfaces:
ConfigurableHandle<H,​CTX>, ConfigurableHandle.ConfigureAutomatonHandle<H,​CTX>, ConfigurableLifeCycleComponentHandle<H,​CTX>, DestroyableHandle<H>, DestroyableHandle.DestroyAutomatonHandle<H>, InitializableHandle<H>, InitializedHandle<H>, LifeCycleComponentHandle<H>, LifeCycleStatusHandle<H>, PausableHandle<H>, PausableHandle.PauseAutomatonHandle<H>, ResumableHandle<H>, ResumableHandle.ResumeAutomatonHandle<H>, RunningHandle<H>, StartableHandle<H>, StartableHandle.StartAutomatonHandle<H>, StoppableHandle<H>, StoppableHandle.StopAutomatonHandle<H>
Enclosing interface:
ConfigurableLifeCycleComponentHandle<H,​CTX>

public static interface ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,​CTX>
extends ConfigurableLifeCycleComponentHandle<H,​CTX>, ConfigurableHandle.ConfigureAutomatonHandle<H,​CTX>, StartableHandle.StartAutomatonHandle<H>, PausableHandle.PauseAutomatonHandle<H>, ResumableHandle.ResumeAutomatonHandle<H>, StoppableHandle.StopAutomatonHandle<H>, DestroyableHandle.DestroyAutomatonHandle<H>, LifeCycleComponentHandle<H>, LifeCycleStatusHandle<H>
The ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle is an automaton managing various LifeCycleStatus states for Component instances each related to a handle. Operations manipulating on the LifeCycleStatus are invoked by this ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle with a handle identifying the according referenced Component. The LifeCycleComponent contains the business-logic where as the ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle provides the frame for managing this business-logic. The ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle takes care of the correct life-cycle applied on a LifeCycleComponent.