- Type Parameters:
CON- The type of the connection to be used.
- All Known Subinterfaces:
ConnectionAccessor.ConnectionProperty<CON>
public interface ConnectionAccessor<CON>
Provides an accessor for a connection property for e.g. an
InputStream or an OutputStream.-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceConnectionAccessor.ConnectionMutator<CON>Provides a mutator for a connection property for e.g. anInputStreamor anOutputStream.static interfaceConnectionAccessor.ConnectionProperty<CON>Provides a connection property for e.g. anInputStreamor anOutputStream. -
Method Summary
Modifier and Type Method Description CONgetConnection()Retrieves the connection from the connection property.
-
Method Details
-
getConnection
CON getConnection()Retrieves the connection from the connection property.- Returns:
- The connection stored by the connection property.
-