Interface ConnectionOpenable.ConnectionOpenAutomaton<CON>

Type Parameters:
CON - The type of the connection to be used.
All Superinterfaces:
ConnectionOpenable<CON>, OpenedAccessor
All Known Subinterfaces:
ConnectionComponent.ConnectionAutomaton<CON>
All Known Implementing Classes:
ConnectionAutomatonImpl
Enclosing interface:
ConnectionOpenable<CON>

public static interface ConnectionOpenable.ConnectionOpenAutomaton<CON> extends ConnectionOpenable<CON>, OpenedAccessor
The ConnectionOpenable.ConnectionOpenAutomaton interface defines those methods related to the opening of connection(s) life-cycle. The semantics of this interface is very similar to that of the Configurable.ConfigureAutomaton interface. To clarify the context regarding connections, the ConnectionOpenable.ConnectionOpenAutomaton interface has been introduced.