Interface ConnectionOpenable.ConnectionOpenBuilder<CON,B extends ConnectionOpenable.ConnectionOpenBuilder<CON,B>>

Type Parameters:
CON - the generic type
B - The instance to be returned on which to apply succeeding builder operations.
All Known Subinterfaces:
ConnectionComponent.ConnectionComponentBuilder<CON,B>
Enclosing interface:
ConnectionOpenable<CON>

public static interface ConnectionOpenable.ConnectionOpenBuilder<CON,B extends ConnectionOpenable.ConnectionOpenBuilder<CON,B>>
To enable the Startable functionality to be invoked in a builder chain.