Interface ConnectionStatusAccessor
- All Superinterfaces:
OpenedAccessor
- All Known Subinterfaces:
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>, ConnectableComponent.ConnectableAutomaton, ConnectionComponent.ConnectionAutomaton<CON>, ConnectionStatusAccessor.ConnectionStatusProperty, LinkComponent.LinkAutomaton
- All Known Implementing Classes:
AbstractConnectableAutomaton, AbstractDeviceAutomaton, ConnectionAutomatonImpl, LinkAutomatonImpl
Provides an accessor for a
ConnectionStatus property.-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a mutator for aConnectionStatusproperty.static interfaceProvides aConnectionStatusproperty.Nested classes/interfaces inherited from interface OpenedAccessor
OpenedAccessor.OpenedMutator, OpenedAccessor.OpenedProperty -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theConnectionStatusproperty from the property.default booleanisOpened()Determines whether the connection is ought to be open or not.
-
Method Details
-
getConnectionStatus
ConnectionStatus getConnectionStatus()Retrieves theConnectionStatusproperty from the property. Determines in whichConnectionStatusstatus a component is in.- Returns:
- Returns the
ConnectionStatusproperty stored by the property.
-
isOpened
default boolean isOpened()Determines whether the connection is ought to be open or not.- Specified by:
isOpenedin interfaceOpenedAccessor- Returns:
- True in case the connection is open, else the connection is
either closed or of a status
ConnectionStatus.NONE.
-