Interface ContextAccessor.ContextBuilder<CTX,B extends ContextAccessor.ContextBuilder<CTX,B>>
- Type Parameters:
CTX- the generic typeB- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
ContextAccessor<CTX>
public static interface ContextAccessor.ContextBuilder<CTX,B extends ContextAccessor.ContextBuilder<CTX,B>>
Provides a builder method for a context property returning the builder
for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptionwithContext(CTX aContext) Sets the context for the context property.
-
Method Details
-
withContext
-