Interface ContextAccessor.ContextProperty<CTX>
- Type Parameters:
CTX- The type of the context property.
- All Superinterfaces:
ContextAccessor<CTX>, ContextAccessor.ContextMutator<CTX>
- Enclosing interface:
ContextAccessor<CTX>
public static interface ContextAccessor.ContextProperty<CTX>
extends ContextAccessor<CTX>, ContextAccessor.ContextMutator<CTX>
Provides a context property for e.g. a service or a component.
-
Nested Class Summary
Nested classes/interfaces inherited from interface ContextAccessor
ContextAccessor.ContextBuilder<CTX,B>, ContextAccessor.ContextMutator<CTX>, ContextAccessor.ContextProperty<CTX> -
Method Summary
Modifier and TypeMethodDescriptiondefault CTXletContext(CTX aContext) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given context (setter) as ofContextAccessor.ContextMutator.setContext(Object)and returns the very same value (getter).Methods inherited from interface ContextAccessor
getContextMethods inherited from interface ContextAccessor.ContextMutator
setContext
-
Method Details
-
letContext
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given context (setter) as ofContextAccessor.ContextMutator.setContext(Object)and returns the very same value (getter).- Parameters:
aContext- The context to set (viaContextAccessor.ContextMutator.setContext(Object)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-