Interface Decomposeable

All Known Subinterfaces:
CompositeComponent, CompositeComponent.ExtendedCompositeComponent<CTX,​CON>, Decomposeable.DecomposeAutomaton
All Known Implementing Classes:
CompositeComponentImpl, CompositeComponentImpl.ExtendedCompositeComponentImpl

public interface Decomposeable
This mixin might be implemented by a component in order to provide decomposition facilities. No exception is thrown as decomposition must work always!

The "decompose()" method decompose() differs from the "destroy()" method Destroyable.destroy() in that "destroy()" shuts down the component in memory, whereas "decompose()" also tears down external resources such as files or DB schemas. This means that with "decompose()" all external data will be lost, as with "destroy()" external data will be kept (in terms that it makes sense for the actual implementation).

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  Decomposeable.DecomposeAutomaton
    The Decomposeable.DecomposeAutomaton interface defines those methods related to the decompose life-cycle.
  • Method Summary

    Modifier and Type Method Description
    void decompose()
    Decomposes the component.
  • Method Details

    • decompose

      void decompose()
      Decomposes the component. External resources might get deleted (such as files or DB schemas)!