- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
DecomposeableHandle.DecomposeAutomatonHandle<H>
public interface DecomposeableHandle<H>
The
DecomposeableHandle interface defines those methods related to
the handle based decompose life-cycle.
The handle reference requires the Decomposeable interface to be
implemented.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheDecomposeableHandle.DecomposeAutomatonHandleinterface defines those methods related to the handle based decompose life-cycle. -
Method Summary
Modifier and TypeMethodDescriptionvoidDecomposes the component identified by the given handle.booleanhasDecomposeable(H aHandle) Determines whether the handle reference is decomposable by implementing theDecomposeableinterface.
-
Method Details
-
hasDecomposeable
Determines whether the handle reference is decomposable by implementing theDecomposeableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleRuntimeException- in case the handle is unknown.
-
decompose
void decompose(H aHandle) throws UnknownHandleRuntimeException, UnsupportedHandleOperationRuntimeException Decomposes the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
UnknownHandleRuntimeException- in case the given handle is unknown.UnsupportedHandleOperationRuntimeException- in case the reference of the handle does not support the requested operation.
-