Class DestroyException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap
Thrown in case destroying a component caused problems. Usually a method
similar to "destroy()" throws such an exception. This is a
RuntimeException as destroying a component should always succeed and
a DestroyException should only be thrown in case of obvious
malfunctioning and the philosophy of "fail early!" without forcing a method
to declare an according checked exception!- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classUnchecked exception with the same semantics as theDestroyException.Nested classes/interfaces inherited from class ComponentRuntimeException
ComponentRuntimeException.ComponentHandleRuntimeExceptionNested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionDestroyException(String aMessage) Instantiates the classDestroyException.DestroyException(String aMessage, String aErrorCode) Instantiates the classDestroyException.DestroyException(String aMessage, Throwable aCause) Instantiates the classDestroyException.DestroyException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classDestroyException.DestroyException(Throwable aCause) Instantiates the classDestroyException.DestroyException(Throwable aCause, String aErrorCode) Instantiates the classDestroyException. -
Method Summary
Methods inherited from class AbstractRuntimeException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
DestroyException
Instantiates the classDestroyException.- See Also:
-
DestroyException
Instantiates the classDestroyException.- See Also:
-
DestroyException
Instantiates the classDestroyException.- See Also:
-
DestroyException
-
DestroyException
Instantiates the classDestroyException.- See Also:
-
DestroyException
-