Interface Destroyable.DestroyAutomaton

All Superinterfaces:
Destroyable
All Known Subinterfaces:
ConfigurableLifeCycleComponent.ConfigurableLifeCycleAutomaton<CTX>, LifeCycleComponent.LifeCycleAutomaton
All Known Implementing Classes:
ConfigurableLifeCycleAutomatonImpl, LifeCycleAutomatonImpl, LifeCycleAutomatonImpl.ManualLifeCycleAutomatonImpl
Enclosing interface:
Destroyable

public static interface Destroyable.DestroyAutomaton
extends Destroyable
The Destroyable.DestroyAutomaton interface defines those methods related to the destroy life-cycle.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.component.Destroyable

    Destroyable.DestroyAutomaton
  • Method Summary

    Modifier and Type Method Description
    boolean isDestroyable()
    Determines whether the component may get destroyed.
    boolean isDestroyed()
    Determines whether the component is destroyed.

    Methods inherited from interface org.refcodes.component.Destroyable

    destroy
  • Method Details

    • isDestroyable

      boolean isDestroyable()
      Determines whether the component may get destroyed.
      Returns:
      True if Destroyable.destroy() is possible.
    • isDestroyed

      boolean isDestroyed()
      Determines whether the component is destroyed. In case of being true, then invoking any of that Component instance's methods (except the Destroyable.destroy() method) must throw an IllegalStateException as by definition a once destroyed Component is in the state of being destroyed which is irreversible.
      Returns:
      True in case of being destroyed, else false.