Interface DestroyableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>, ConfigurableLifeCycleComponentHandle<H,​CTX>, ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,​CTX>, DestroyableHandle.DestroyAutomatonHandle<H>, LifeCycleComponentHandle<H>, LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>

public interface DestroyableHandle<H>
The DestroyableHandle interface defines those methods related to the handle based destroy life-cycle.

The handle reference requires the Destroyable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  DestroyableHandle.DestroyAutomatonHandle<H>
    The DestroyableHandle.DestroyAutomatonHandle interface defines those methods related to the handle based destroy life-cycle.
  • Method Summary

    Modifier and Type Method Description
    void destroy​(H aHandle)
    Destroys the component identified by the given handle.
    boolean hasDestroyable​(H aHandle)
    Determines whether the handle reference is destroyable by implementing the Destroyable interface.