- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
DisposableHandle.DisposeAutomatonHandle<H>
public interface DisposableHandle<H>
The
DisposableHandle interface defines those methods related to the
handle based dispose life-cycle.
The handle reference requires the Disposable.Disposedable interface to be
implemented.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheDisposableHandle.DisposeAutomatonHandleinterface defines those methods related to the handle based dispose life-cycle. -
Method Summary
Modifier and TypeMethodDescriptionvoidDisposes the component identified by the given handle.booleanhasDisposable(H aHandle) Determines whether the handle reference is disposable by implementing theDisposable.Disposedableinterface.
-
Method Details
-
hasDisposable
Determines whether the handle reference is disposable by implementing theDisposable.Disposedableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleRuntimeException- in case the handle is unknown.
-
dispose
void dispose(H aHandle) throws UnknownHandleRuntimeException, UnsupportedHandleOperationRuntimeException, IllegalHandleStateChangeRuntimeException Disposes the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
UnknownHandleRuntimeException- in case the given handle is unknown.UnsupportedHandleOperationRuntimeException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeRuntimeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-