Interface FlushHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
ComponentHandleComposite<H,REF>

public interface FlushHandle<H>
The FlushHandle interface defines those methods related to the handle based flush operation.

The handle reference requires the Flushable interface to be implemented.