Module org.refcodes.component
Package org.refcodes.component
Interface Flushable.FlushBuilder<B extends Flushable.FlushBuilder<B>>
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.component.Flushable
Flushable.FlushBuilder<B extends Flushable.FlushBuilder<B>>
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default BwithFlush()With flush as ofFlushable.flush().default BwithFlushUnchecked()Flushes the component by callingwithFlush()without you to require catching aIOException.-
Methods inherited from interface org.refcodes.component.Flushable
flush, flushUnchecked, isFlushable
-
-
-
-
Method Detail
-
withFlush
default B withFlush() throws IOException
With flush as ofFlushable.flush().- Returns:
- The implementing instance as of the Builder-Pattern.
- Throws:
IOException- in case flushing failed as of some reason.
-
withFlushUnchecked
default B withFlushUnchecked()
Flushes the component by callingwithFlush()without you to require catching aIOException.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
org.refcodes.exception.IORuntimeException- encapsulates the cause and is thrown upon encountering aIOExceptionexception
-
-