- Type Parameters:
H- The type of the handle to be used.
- All Known Subinterfaces:
HandleAccessor.HandleProperty<H>
- All Known Implementing Classes:
HandleTimeoutRuntimeException,IllegalHandleStateChangeRuntimeException,UnknownHandleRuntimeException,UnsupportedHandleOperationRuntimeException
public interface HandleAccessor<H>
Provides an accessor for a handle property for e.g. key / handle pair.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceHandleAccessor.HandleMutator<H>Provides a mutator for a handle property for e.g. key / handle pair.static interfaceHandleAccessor.HandleProperty<H>Provides a handle property for e.g. key / handle pair. -
Method Summary
-
Method Details
-
getHandle
H getHandle()Retrieves the handle from the handle property.- Returns:
- The handle stored by the handle property.
-