Interface HandleDirectory<H,REF>

Type Parameters:
H - The handle used by the HandleDirectory.
REF - The type of the objects to which the handles reference to.
All Superinterfaces:
HandleLookup<H,REF>

public interface HandleDirectory<H,REF> extends HandleLookup<H,REF>
The handle directory enables listing of all known data managed by the implementing component.