Interface HandleLookup<H,REF>

Type Parameters:
H - The type of the handles.
REF - The type of the objects to which the handles reference to.
All Known Subinterfaces:
ComponentHandleComposite<H,REF>, HandleDirectory<H,REF>

public interface HandleLookup<H,REF>
Any system in this framework being able to work with handles provides an implementation of the handle lookup interface. This enables a unified access to the system wide handles.