Class HandleTimeoutRuntimeException

All Implemented Interfaces:
Serializable, HandleAccessor, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap

public class HandleTimeoutRuntimeException extends ComponentRuntimeException.ComponentHandleRuntimeException
This exception is thrown in case a handle was provided which was unknown to the invoked component.
See Also: