Module org.refcodes.component
Package org.refcodes.component
Class IllegalHandleStateChangeRuntimeException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.component.ComponentRuntimeException
org.refcodes.component.IllegalHandleStateChangeRuntimeException
- All Implemented Interfaces:
Serializable,HandleAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
This exception is thrown in case a handle was provided whose reference does
not support a given operation.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.component.HandleAccessor
HandleAccessor.HandleMutator<H>, HandleAccessor.HandleProperty<H> -
Constructor Summary
ConstructorsConstructorDescriptionIllegalHandleStateChangeRuntimeException(Object aHandle, String aMessage) Instantiates a new illegale handle state change runtime exception.IllegalHandleStateChangeRuntimeException(Object aHandle, String aMessage, String aErrorCode) Instantiates a new illegale handle state change runtime exception.IllegalHandleStateChangeRuntimeException(Object aHandle, String aMessage, Throwable aCause) Instantiates a new illegale handle state change runtime exception.IllegalHandleStateChangeRuntimeException(Object aHandle, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new illegale handle state change runtime exception.IllegalHandleStateChangeRuntimeException(Object aHandle, Throwable aCause) Instantiates a new illegale handle state change runtime exception.IllegalHandleStateChangeRuntimeException(Object aHandle, Throwable aCause, String aErrorCode) Instantiates a new illegale handle state change runtime exception. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractRuntimeException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
IllegalHandleStateChangeRuntimeException
Instantiates a new illegale handle state change runtime exception.- Parameters:
aHandle- the handleaMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
IllegalHandleStateChangeRuntimeException
public IllegalHandleStateChangeRuntimeException(Object aHandle, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new illegale handle state change runtime exception. -
IllegalHandleStateChangeRuntimeException
Instantiates a new illegale handle state change runtime exception. -
IllegalHandleStateChangeRuntimeException
Instantiates a new illegale handle state change runtime exception.- Parameters:
aHandle- the handleaMessage- The aMessage describing this exception.
-
IllegalHandleStateChangeRuntimeException
public IllegalHandleStateChangeRuntimeException(Object aHandle, Throwable aCause, String aErrorCode) Instantiates a new illegale handle state change runtime exception. -
IllegalHandleStateChangeRuntimeException
Instantiates a new illegale handle state change runtime exception.
-
-
Method Details
-
getHandle
Gets the handle.- Specified by:
getHandlein interfaceHandleAccessor- Returns:
- the handle
-