- All Known Subinterfaces:
CompositeComponent,CompositeComponent.ExtendedCompositeComponent<CTX,CON>,Initializable.InitializeAutomaton,Initializable.UncheckedInitializable,InitializableComponent,LifeCycleComponent,LifeCycleComponent.LifeCycleAutomaton,LifeCycleComponent.UncheckedLifeCycleComponent
- All Known Implementing Classes:
CompositeComponentImpl,CompositeComponentImpl.ExtendedCompositeComponentImpl,LifeCycleAutomatonImpl,LifeCycleAutomatonImpl.ManualLifeCycleAutomatonImpl
public interface Initializable
This mixin might be implemented by a component in order to provide
initializing facilities.
In case a context is to be provided to the initialize() method, you
may use the Configurable interface with its
Configurable.initialize(Object) method, which provides an argument
specifying the context to be passed to the Component.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceInitializable.InitializeAutomatonTheInitializable.InitializeAutomatoninterface defines those methods related to the initialize life-cycle.static interfaceInitializable.InitializeBuilder<B extends Initializable.InitializeBuilder<B>>To enable theInitializablefunctionality to be invoked in a builder chain.static interfaceInitializable.UncheckedInitializableSeeInitializablewithout any checked exception being declared. -
Method Summary
Modifier and Type Method Description voidinitialize()Initialize the component.default voidinitializeUnchecked()Initialize the component by callinginitialize()without you to require catching anInitializeException.
-
Method Details
-
initialize
Initialize the component.- Throws:
InitializeException- Thrown in case initializing fails.
-
initializeUnchecked
default void initializeUnchecked()Initialize the component by callinginitialize()without you to require catching anInitializeException.- Throws:
InitializeException.InitializeRuntimeException- encapsulates the cause and is thrown upon encountering aInitializeExceptionexception
-