Interface LifeCycleComponent

All Superinterfaces:
Destroyable, Initializable, Pausable, Resumable, Startable, Stoppable
All Known Subinterfaces:
CompositeComponent, CompositeComponent.ExtendedCompositeComponent<CTX,​CON>, LifeCycleComponent.LifeCycleAutomaton, LifeCycleComponent.UncheckedLifeCycleComponent
All Known Implementing Classes:
CompositeComponentImpl, CompositeComponentImpl.ExtendedCompositeComponentImpl, LifeCycleAutomatonImpl, LifeCycleAutomatonImpl.ManualLifeCycleAutomatonImpl

public interface LifeCycleComponent
extends Initializable, Startable, Pausable, Resumable, Stoppable, Destroyable
A component implementing the LifeCycleComponent interface supports a life-cycle. I.e. such a component may be instructed from the outside to run through several stages from getting started till being destroyed. The valid state changes are mainly as follows: "initialize" - "start" - "pause" - "resume" - "stop" - "destroy" For example: "initialize" - "start" - "pause" - "resume" - "pause" - "resume" - "stop" - "start" - "pause" - "resume" - "stop" - "destroy" The LifeCycleComponentHandle.LifeCycleAutomatonHandle is a component managing various LifeCycleComponents each identified by a dedicated handle. Operations on the LifeCycleComponent are invoked by this LifeCycleComponentHandle.LifeCycleAutomatonHandle with a handle identifying the according LifeCycleComponent.

The LifeCycleComponent contains the business-logic where as the LifeCycleComponentHandle.LifeCycleAutomatonHandle provides the frame for managing this business-logic. The LifeCycleComponent.LifeCycleAutomaton takes care of the correct life-cycle applied on a LifeCycleComponent.