Interface LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>

Type Parameters:
H - The type of the handle.
All Superinterfaces:
DestroyableHandle<H>, DestroyableHandle.DestroyAutomatonHandle<H>, InitializableHandle<H>, InitializableHandle.InitializeAutomatonHandle<H>, InitializedHandle<H>, LifeCycleComponentHandle<H>, LifeCycleStatusHandle<H>, PausableHandle<H>, PausableHandle.PauseAutomatonHandle<H>, ResumableHandle<H>, ResumableHandle.ResumeAutomatonHandle<H>, RunningHandle<H>, StartableHandle<H>, StartableHandle.StartAutomatonHandle<H>, StoppableHandle<H>, StoppableHandle.StopAutomatonHandle<H>
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>
Enclosing interface:
LifeCycleComponentHandle<H>

public static interface LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>
extends LifeCycleComponentHandle<H>, InitializableHandle.InitializeAutomatonHandle<H>, StartableHandle.StartAutomatonHandle<H>, PausableHandle.PauseAutomatonHandle<H>, ResumableHandle.ResumeAutomatonHandle<H>, StoppableHandle.StopAutomatonHandle<H>, DestroyableHandle.DestroyAutomatonHandle<H>, LifeCycleStatusHandle<H>
The LifeCycleComponentHandle.LifeCycleAutomatonHandle is an automaton managing various LifeCycleStatus states for Component instances each related to a handle. Operations manipulating on the LifeCycleStatus are invoked by this LifeCycleComponentHandle.LifeCycleAutomatonHandle with a handle identifying the according referenced Component. The LifeCycleComponent contains the business-logic where as the LifeCycleComponentHandle.LifeCycleAutomatonHandle provides the frame for managing this business-logic. The LifeCycleComponentHandle.LifeCycleAutomatonHandle takes care of the correct life-cycle applied on a LifeCycleComponent.