Module org.refcodes.component
Package org.refcodes.component
Interface LifeCycleRequestAccessor.LifeCycleRequestProperty
-
- All Superinterfaces:
LifeCycleRequestAccessor,LifeCycleRequestAccessor.LifeCycleRequestMutator
- Enclosing interface:
- LifeCycleRequestAccessor
public static interface LifeCycleRequestAccessor.LifeCycleRequestProperty extends LifeCycleRequestAccessor, LifeCycleRequestAccessor.LifeCycleRequestMutator
Provides aLifeCycleRequestproperty.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.component.LifeCycleRequestAccessor
LifeCycleRequestAccessor.LifeCycleRequestMutator, LifeCycleRequestAccessor.LifeCycleRequestProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default LifeCycleRequestletLifeCycleRequest(LifeCycleRequest aLifeCycleRequest)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLifeCycleRequest(setter) as ofLifeCycleRequestAccessor.LifeCycleRequestMutator.setLifeCycleRequest(LifeCycleRequest)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.component.LifeCycleRequestAccessor
getLifeCycleRequest
-
Methods inherited from interface org.refcodes.component.LifeCycleRequestAccessor.LifeCycleRequestMutator
setLifeCycleRequest
-
-
-
-
Method Detail
-
letLifeCycleRequest
default LifeCycleRequest letLifeCycleRequest(LifeCycleRequest aLifeCycleRequest)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLifeCycleRequest(setter) as ofLifeCycleRequestAccessor.LifeCycleRequestMutator.setLifeCycleRequest(LifeCycleRequest)and returns the very same value (getter).- Parameters:
aLifeCycleRequest- TheLifeCycleRequestto set (viaLifeCycleRequestAccessor.LifeCycleRequestMutator.setLifeCycleRequest(LifeCycleRequest)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
-