-
- All Known Subinterfaces:
LifecycleRequestAccessor.LifecycleRequestProperty
public interface LifecycleRequestAccessorProvides an accessor for aLifecycleRequestproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceLifecycleRequestAccessor.LifecycleRequestMutatorProvides a mutator for aLifecycleRequestproperty.static interfaceLifecycleRequestAccessor.LifecycleRequestPropertyProvides aLifecycleRequestproperty.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description LifecycleRequestgetLifecycleRequest()Retrieves theLifecycleRequestproperty from the property.
-
-
-
Method Detail
-
getLifecycleRequest
LifecycleRequest getLifecycleRequest()
Retrieves theLifecycleRequestproperty from the property. Determines in whichLifecycleRequestis being requested for a component.- Returns:
- Returns the
LifecycleRequestproperty stored by the property.
-
-