-
- Type Parameters:
H- the generic type
- All Known Subinterfaces:
CompositeComponentHandle<H,REF>,ConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H,CTX>,LifecycleComponentHandle.LifecycleAutomatonHandle<H>
public interface LifecycleStatusHandle<H>The Interface LifecycleStatusHandle.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description LifecycleStatusgetLifecycleStatus(H aHandle)Retrieves theLifecycleStatusrelated to the given handle.booleanhasLifecycleStatus(H aHandle)Determines whether the handle reference provides aLifecycleStatusby implementing theLifecycleStatusAccessorinterface.
-
-
-
Method Detail
-
hasLifecycleStatus
boolean hasLifecycleStatus(H aHandle) throws UnknownHandleRuntimeException
Determines whether the handle reference provides aLifecycleStatusby implementing theLifecycleStatusAccessorinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleRuntimeException- in case the handle is unknown.
-
getLifecycleStatus
LifecycleStatus getLifecycleStatus(H aHandle) throws UnknownHandleRuntimeException, UnsupportedHandleOperationRuntimeException
Retrieves theLifecycleStatusrelated to the given handle. Determines in whichLifecycleStatusstatus a component related to the given handle is in.- Parameters:
aHandle- The handle for which to retrieve theLifecycleStatus.- Returns:
- Returns the
LifecycleStatusrelated to the given handle. - Throws:
UnknownHandleRuntimeException- in case the given handle is unknown.UnsupportedHandleOperationRuntimeException- in case the reference of the handle does not support the requested operation.
-
-