Interface Openable.OpenBuilder<B extends Openable.OpenBuilder<B>>
- Type Parameters:
B- The instance to be returned on which to apply succeeding builder operations.
- All Known Subinterfaces:
LinkComponent.LinkComponentBuilder<B>
- Enclosing interface:
Openable
public static interface Openable.OpenBuilder<B extends Openable.OpenBuilder<B>>
To enable the
Startable functionality to be invoked in a builder
chain.-
Method Summary
-
Method Details
-
withOpen
Builder method for theOpenable.open()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-