Interface OpenableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
LinkComponentHandle<H>, LinkComponentHandle.LinkAutomatonHandle<H>, OpenableHandle.OpenAutomatonHandle<H>

public interface OpenableHandle<H>
The OpenableHandle interface defines those methods related to the handle based open/connect life-cycle.

The handle reference requires the Openable interface to be implemented.