- All Known Subinterfaces:
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>,BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT>,ConnectableComponent.ConnectableAutomaton,ConnectionComponent.ConnectionAutomaton<CON>,ConnectionOpenable.ConnectionOpenAutomaton<CON>,ConnectionStatusAccessor,ConnectionStatusAccessor.ConnectionStatusProperty,LinkComponent.LinkAutomaton,Openable.OpenAutomaton,OpenedAccessor.OpenedProperty
- All Known Implementing Classes:
AbstractConnectableAutomaton,AbstractDeviceAutomaton,ConnectionAutomatonImpl,LinkAutomatonImpl
public interface OpenedAccessor
Provides an accessor for a opened property.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceOpenedAccessor.OpenedMutatorProvides a mutator for a opened property.static interfaceOpenedAccessor.OpenedPropertyProvides a opened property. -
Method Summary
Modifier and Type Method Description booleanisOpened()Retrieves the is-opened property from the opened property.
-
Method Details
-
isOpened
boolean isOpened()Retrieves the is-opened property from the opened property. Determines whether the component's connection is opened. A component's connection is opened after being opened as ofOpenable.open()orConnectionOpenable.open(Object).- Returns:
- True in case of being opened (returns the is-opened property stored by the opened property).
-