Interface Pausable
- All Known Subinterfaces:
ComponentComposite, ComponentComposite.ExtendedComponentComposite<CTX,CON>, ConfigurableLifecycleComponent<CTX>, ConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX>, LifecycleComponent, LifecycleComponent.LifecycleAutomaton, LifecycleComponent.UncheckedLifecycleComponent, Pausable.PauseAutomaton, Pausable.UncheckedPausable
- All Known Implementing Classes:
AbstractComponentComposite, AbstractComponentComposite.ExtendedCompositeComponentImpl, ConfigurableLifecycleAutomatonImpl, LifecycleMachine, LifecycleMachine.ManualLifecycleMachine
public interface Pausable
This mixin might be implemented by a component in order to provide pause
facilities.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceThePausable.PauseAutomatoninterface defines those methods related to the pause life-cycle.static interfacePausable.PauseBuilder<B extends Pausable.PauseBuilder<B>>To enable thePausablefunctionality to be invoked in a builder chain.static interfaceSeePausablewithout any checked exception being declared. -
Method Summary
Modifier and TypeMethodDescriptionvoidpause()Pauses the component.default voidPauses the component by callingpause()without you to require catching anPauseException.
-
Method Details
-
pause
Pauses the component.- Throws:
PauseException- in case pausing fails.
-
pauseUnchecked
default void pauseUnchecked()Pauses the component by callingpause()without you to require catching anPauseException.- Throws:
PauseException.PauseRuntimeException- encapsulates the aCause and is thrown upon encountering aPauseExceptionexception
-