Interface Pausable.PauseBuilder<B extends Pausable.PauseBuilder<B>>

Type Parameters:
B - The instance to be returned on which to apply succeeding builder operations.
Enclosing interface:
Pausable

public static interface Pausable.PauseBuilder<B extends Pausable.PauseBuilder<B>>
To enable the Pausable functionality to be invoked in a builder chain.
  • Method Summary

    Modifier and Type
    Method
    Description
    Builder method for the Pausable.pause() method.
  • Method Details

    • withPause

      B withPause() throws PauseException
      Builder method for the Pausable.pause() method.
      Returns:
      The instance to be returned on which to apply succeeding builder operations.
      Throws:
      PauseException - Thrown in case pausing fails.