Interface PausableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
ComponentHandleComposite<H,REF>, ConfigurableLifecycleComponentHandle<H,CTX>, ConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H,CTX>, LifecycleComponentHandle<H>, LifecycleComponentHandle.LifecycleAutomatonHandle<H>, PausableHandle.PauseAutomatonHandle<H>

public interface PausableHandle<H>
The PausableHandle interface defines those methods related to the handle based pause life-cycle.

The handle reference requires the Pausable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type
    Interface
    Description
    static interface 
    The PausableHandle.PauseAutomatonHandle interface defines those methods related to the handle based pause life-cycle.
  • Method Summary

    Modifier and Type
    Method
    Description
    boolean
    hasPausable(H aHandle)
    Determines whether the handle reference is pausable by implementing the Pausable interface.
    void
    pause(H aHandle)
    Pauses the component identified by the given handle.
  • Method Details

    • hasPausable

      boolean hasPausable(H aHandle)
      Determines whether the handle reference is pausable by implementing the Pausable interface.
      Parameters:
      aHandle - The handle to test whether the reference provides the according functionality.
      Returns:
      True in case the reference provides the according functionality.
      Throws:
      UnknownHandleException - in case the handle is unknown.
    • pause

      void pause(H aHandle) throws PauseException
      Pauses the component identified by the given handle.
      Parameters:
      aHandle - The handle identifying the component.
      Throws:
      PauseException - in case pausing fails.
      UnknownHandleException - in case the given handle is unknown.
      UnsupportedHandleOperationException - in case the reference of the handle does not support the requested operation.
      IllegalHandleStateChangeException - Thrown in case a state change is not possible due to the current state the referenced component is in.