Interface ProgressHandle<H>

Type Parameters:
H - the generic type
All Known Subinterfaces:
ComponentHandleComposite<H,REF>

public interface ProgressHandle<H>
Whenever a handle is associated with a progress, then a component providing such handles should implement this interface.

The handle reference requires the ProgressAccessor interface to be implemented.