Interface ReloadHandle<H>

Type Parameters:
H - The type of the handle.

public interface ReloadHandle<H>
The ReloadHandle interface defines those methods related to the handle based reload operation.

The handle reference requires the Reloadable interface to be implemented.