Module org.refcodes.component
Package org.refcodes.component
Interface Reloadable.ReloadBuilder<B extends Reloadable.ReloadBuilder<B>>
-
- Type Parameters:
B- the generic type
- All Superinterfaces:
Reloadable
- Enclosing interface:
- Reloadable
public static interface Reloadable.ReloadBuilder<B extends Reloadable.ReloadBuilder<B>> extends Reloadable
The Interface ReloadBuilder.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.component.Reloadable
Reloadable.ReloadBuilder<B extends Reloadable.ReloadBuilder<B>>
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default BwithReload()With reload as ofReloadable.reload().default BwithReloadUnchecked()Reloads the component by callingwithReload()without you to require catching aIOException.-
Methods inherited from interface org.refcodes.component.Reloadable
reload, reloadUnchecked
-
-
-
-
Method Detail
-
withReload
default B withReload() throws IOException
With reload as ofReloadable.reload().- Returns:
- The implementing instance as of the Builder-Pattern.
- Throws:
IOException- in case reloading failed as of some reason.
-
withReloadUnchecked
default B withReloadUnchecked()
Reloads the component by callingwithReload()without you to require catching aIOException.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
org.refcodes.exception.IORuntimeException- encapsulates the cause and is thrown upon encountering aIOExceptionexception
-
-