Interface ResetHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
ComponentHandleComposite<H,REF>

public interface ResetHandle<H>
The ResetHandle interface defines those methods related to the handle based reset operation.

The handle reference requires the Resetable interface to be implemented.