Interface Resetable

All Known Subinterfaces:
CompositeComponent, CompositeComponent.ExtendedCompositeComponent<CTX,​CON>
All Known Implementing Classes:
CompositeComponentImpl, CompositeComponentImpl.ExtendedCompositeComponentImpl

public interface Resetable
This mixin might be implemented by a component in order to provide reset facilities. A call to reset() sets the component into a defined state keeping the component is still up and running after resetting.
  • Method Summary

    Modifier and Type Method Description
    void reset()
    Resets the component.
  • Method Details

    • reset

      void reset()
      Resets the component. No exception is thrown as decomposition must work always!