Interface Resumable
- All Known Subinterfaces:
ComponentComposite, ComponentComposite.ExtendedComponentComposite<CTX,CON>, ConfigurableLifecycleComponent<CTX>, ConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX>, LifecycleComponent, LifecycleComponent.LifecycleAutomaton, LifecycleComponent.UncheckedLifecycleComponent, Resumable.ResumeAutomaton, Resumable.UncheckedResumable
- All Known Implementing Classes:
AbstractComponentComposite, AbstractComponentComposite.ExtendedCompositeComponentImpl, ConfigurableLifecycleAutomatonImpl, LifecycleMachine, LifecycleMachine.ManualLifecycleMachine
public interface Resumable
This mixin might be implemented by a component in order to provide resume
facilities.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheResumable.ResumeAutomatoninterface defines those methods related to the resume life-cycle.static interfaceResumable.ResumeBuilder<B extends Resumable.ResumeBuilder<B>>To enable theResumablefunctionality to be invoked in a builder chain.static interfaceSeeResumablewithout any checked exception being declared. -
Method Summary
-
Method Details
-
resume
Resumes the component.- Throws:
ResumeException- Thrown in case resuming fails.
-