Interface Resumable.ResumeBuilder<B extends Resumable.ResumeBuilder<B>>
- Type Parameters:
B- The instance to be returned on which to apply succeeding builder operations.
- Enclosing interface:
Resumable
public static interface Resumable.ResumeBuilder<B extends Resumable.ResumeBuilder<B>>
To enable the
Resumable functionality to be invoked in a builder
chain.-
Method Summary
-
Method Details
-
withResume
Builder method for theResumable.resume()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
ResumeException- Thrown in case resuming fails.
-