Interface RunningAccessor

All Known Subinterfaces:
ConfigurableLifeCycleComponent.ConfigurableLifeCycleAutomaton<CTX>, HealthChecker, LifeCycleComponent.LifeCycleAutomaton, Resumable.ResumeAutomaton, RunningAccessor.RunningProperty, Startable.StartAutomaton
All Known Implementing Classes:
ConfigurableLifeCycleAutomatonImpl, LifeCycleAutomatonImpl, LifeCycleAutomatonImpl.ManualLifeCycleAutomatonImpl

public interface RunningAccessor
Provides an accessor for a running property.
  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  RunningAccessor.RunningMutator
    Provides a mutator for a running property.
    static interface  RunningAccessor.RunningProperty
    Provides a running property.
  • Method Summary

    Modifier and Type Method Description
    boolean isRunning()
    Retrieves the is-running property from the running property.
  • Method Details

    • isRunning

      boolean isRunning()
      Retrieves the is-running property from the running property. Determines whether the component is running. A component is running after being started or being resumed as of Startable.start() or Resumable.resume().
      Returns:
      True in case of being resumed or started (returns the is-running property stored by the running property).