- All Known Subinterfaces:
CompositeComponent,CompositeComponent.ExtendedCompositeComponent<CTX,CON>,ConfigurableLifeCycleComponent<CTX>,ConfigurableLifeCycleComponent.ConfigurableLifeCycleAutomaton<CTX>,LifeCycleComponent,LifeCycleComponent.LifeCycleAutomaton,LifeCycleComponent.UncheckedLifeCycleComponent,Startable.StartAutomaton,Startable.UncheckedStartable
- All Known Implementing Classes:
CompositeComponentImpl,CompositeComponentImpl.ExtendedCompositeComponentImpl,ConfigurableLifeCycleAutomatonImpl,LifeCycleAutomatonImpl,LifeCycleAutomatonImpl.ManualLifeCycleAutomatonImpl
public interface Startable
This mixin might be implemented by a component in order to provide start
facilities.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceStartable.StartAutomatonTheStartable.StartAutomatoninterface defines those methods related to the start life-cycle.static interfaceStartable.StartBuilder<B extends Startable.StartBuilder<B>>To enable theStartablefunctionality to be invoked in a builder chain.static interfaceStartable.UncheckedStartableSeeStartablewithout any checked exception being declared. -
Method Summary
Modifier and Type Method Description voidstart()Starts the component.default voidstartUnchecked()Starts the component by callingstart()without you to require catching anStartException.
-
Method Details
-
start
Starts the component.- Throws:
StartException- Thrown in case starting fails.
-
startUnchecked
default void startUnchecked()Starts the component by callingstart()without you to require catching anStartException.- Throws:
StartException.StartRuntimeException- encapsulates the cause and is thrown upon encountering aStartExceptionexception
-