Interface Startable.StartBuilder<B extends Startable.StartBuilder<B>>

Type Parameters:
B - The instance to be returned on which to apply succeeding builder operations.
Enclosing interface:
Startable

public static interface Startable.StartBuilder<B extends Startable.StartBuilder<B>>
To enable the Startable functionality to be invoked in a builder chain.
  • Method Summary

    Modifier and Type
    Method
    Description
    Builder method for the Startable.start() method.
  • Method Details

    • withStart

      B withStart() throws StartException
      Builder method for the Startable.start() method.
      Returns:
      The instance to be returned on which to apply succeeding builder operations.
      Throws:
      StartException - Thrown in case starting fails.