Interface Stoppable
- All Known Subinterfaces:
ComponentComposite, ComponentComposite.ExtendedComponentComposite<CTX,CON>, ConfigurableLifecycleComponent<CTX>, ConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX>, LifecycleComponent, LifecycleComponent.LifecycleAutomaton, LifecycleComponent.UncheckedLifecycleComponent, Stoppable.StopAutomaton, Stoppable.UncheckedStoppable
- All Known Implementing Classes:
AbstractComponentComposite, AbstractComponentComposite.ExtendedCompositeComponentImpl, ConfigurableLifecycleAutomatonImpl, LifecycleMachine, LifecycleMachine.ManualLifecycleMachine
public interface Stoppable
This mixin might be implemented by a component in order to provide stop
facilities.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheStoppable.StopAutomatoninterface defines those methods related to the stop life-cycle.static interfaceStoppable.StopBuilder<B extends Stoppable.StopBuilder<B>>To enable theStoppablefunctionality to be invoked in a builder chain.static interfaceSeeStoppablewithout any checked exception being declared. -
Method Summary
Modifier and TypeMethodDescriptionvoidstop()Stops the component.default voidStops the component by callingstop()without you to require catching anStopException.
-
Method Details
-
stop
Stops the component.- Throws:
StopException- Thrown in case stopping fails.
-
stopUnchecked
default void stopUnchecked()Stops the component by callingstop()without you to require catching anStopException.- Throws:
StopException.StopRuntimeException- encapsulates the aCause and is thrown upon encountering aStopExceptionexception
-