Interface StoppableHandle<H>
- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
ComponentHandleComposite<H,REF>, ConfigurableLifecycleComponentHandle<H, CTX>, ConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H, CTX>, LifecycleComponentHandle<H>, LifecycleComponentHandle.LifecycleAutomatonHandle<H>, StoppableHandle.StopAutomatonHandle<H>
public interface StoppableHandle<H>
The
StoppableHandle interface defines those methods related to the
handle based stop life-cycle.
The handle reference requires the Stoppable interface to be
implemented.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheStoppableHandle.StopAutomatonHandleinterface defines those methods related to the handle based stop life-cycle. -
Method Summary
Modifier and TypeMethodDescriptionbooleanhasStoppable(H aHandle) Determines whether the handle reference is stoppable by implementing theStoppableinterface.voidStops the component identified by the given handle.
-
Method Details
-
hasStoppable
Determines whether the handle reference is stoppable by implementing theStoppableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleException- in case the handle is unknown.
-
stop
Stops the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
StopException- in case stopping fails.UnknownHandleException- in case the given handle is unknown.UnsupportedHandleOperationException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-