Class UnknownHandleRuntimeException

All Implemented Interfaces:
Serializable, HandleAccessor, ErrorCodeAccessor, Trap

public class UnknownHandleRuntimeException extends ComponentRuntimeException.ComponentHandleRuntimeException
This exception is thrown in case a handle was provided which was unknown to the invoked component.
See Also: