Class UnsupportedHandleOperationRuntimeException

All Implemented Interfaces:
Serializable, HandleAccessor, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap

public class UnsupportedHandleOperationRuntimeException extends ComponentRuntimeException.ComponentHandleRuntimeException
This exception is thrown in case a handle was provided whose reference does not support a given operation.
See Also: