class
Thrown in case ceasing a component caused problems.
static class
class
Thrown in case closing a component caused problems.
static class
protected static class
This exception is the base exception for handle related runtime
exceptions.
class
Thrown in case initializing a component caused problems.
class
Thrown in case decomposing a component caused problems.
class
Thrown in case destroying a component caused problems.
class
class
Thrown in case disposing a component caused problems.
class
This exception is thrown in case a handle was provided which was unknown to
the invoked component.
class
This exception is thrown in case a handle was provided whose reference does
not support a given operation.
class
Thrown in case initializing a component caused problems.
class
This exception is the base lifecycle exception .
class
Thrown in case pausing a component caused problems.
class
Thrown in case resetting a component caused problems.
static class
class
Thrown in case resuming a component caused problems.
class
Thrown in case starting a component caused problems.
class
Thrown in case stopping a component caused problems.
class
This exception is thrown in case a handle was provided which was unknown to
the invoked component.
class
This exception is thrown in case a handle was provided whose reference does
not support a given operation.