Uses of Class
org.refcodes.component.ComponentException.AbstractComponentHandleException
-
Uses of ComponentException.AbstractComponentHandleException in org.refcodes.component
Modifier and TypeClassDescriptionclassThis exception is thrown in case a handle was provided which was unknown to the invoked component.classThis exception is thrown in case a handle was provided whose reference does not support a given operation.classThis exception is thrown in case a handle was provided which was unknown to the invoked component.classThis exception is thrown in case a handle was provided whose reference does not support a given operation.