-
static class
static class
protected static class
This exception is the base exception for handle related runtime
exceptions.
static class
Thrown in case initializing a component caused problems.
static class
class
Thrown in case destroying a component caused problems.
static class
static class
static class
class
This exception is thrown in case a handle was provided which was unknown to
the invoked component.
class
This exception is thrown in case a handle was provided whose reference does
not support a given operation.
static class
Unchecked exception with the same semantics as the
IOException.
static class
This exception is the base lifecycle exception .
static class
static class
static class
static class
static class
Unchecked exception with the same semantics as the
StopException.
class
This exception is thrown in case a handle was provided which was unknown to
the invoked component.
class
This exception is thrown in case a handle was provided whose reference does
not support a given operation.