Uses of Interface
org.refcodes.component.Configurable
-
-
Uses of Configurable in org.refcodes.component
Subinterfaces of Configurable in org.refcodes.component Modifier and Type Interface Description static interfaceCompositeComponent.ExtendedCompositeComponent<CTX,CON>TheCompositeComponent.ExtendedCompositeComponentprovides extended functionality to theCompositeComponent's functionality by including extendedOpenablefunctionality (ConnectionOpenable) and extendsInitializablefunctionality (Configurable).static interfaceConfigurable.ConfigureAutomaton<CTX>TheConfigurable.ConfigureAutomatoninterface defines those methods related to the initialize life-cycle with a provided context.interfaceConfigurableComponent<CTX>AConfigurableComponentcan be configured invoking the methodinitialize(Object).interfaceConfigurableLifecycleComponent<CTX>A component implementing theConfigurableLifecycleComponentinterface supports a life-cycle.static interfaceConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX>A system implementing theConfigurableLifecycleComponent.ConfigurableLifecycleAutomatoninterface supports managingConfigurableLifecycleComponentinstances and takes care that the open/close statuses are invoked in the correct order by throwing according exceptions in case the open/close-cycle is invoked in the wrong order.Classes in org.refcodes.component that implement Configurable Modifier and Type Class Description static classCompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX,CON>TheCompositeComponentImpl.ExtendedCompositeComponentImplis an implementation of theCompositeComponent.ExtendedCompositeComponent.classConfigurableLifecycleAutomatonImpl<CTX>This class implements aConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton.
-