Uses of Interface
org.refcodes.component.ConfigurableLifecycleComponent
-
-
Uses of ConfigurableLifecycleComponent in org.refcodes.component
Subinterfaces of ConfigurableLifecycleComponent in org.refcodes.component Modifier and Type Interface Description static interfaceCompositeComponent.ExtendedCompositeComponent<CTX,CON>TheCompositeComponent.ExtendedCompositeComponentprovides extended functionality to theCompositeComponent's functionality by including extendedOpenablefunctionality (ConnectionOpenable) and extendsInitializablefunctionality (Configurable).static interfaceConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX>A system implementing theConfigurableLifecycleComponent.ConfigurableLifecycleAutomatoninterface supports managingConfigurableLifecycleComponentinstances and takes care that the open/close statuses are invoked in the correct order by throwing according exceptions in case the open/close-cycle is invoked in the wrong order.Classes in org.refcodes.component that implement ConfigurableLifecycleComponent Modifier and Type Class Description static classCompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX,CON>TheCompositeComponentImpl.ExtendedCompositeComponentImplis an implementation of theCompositeComponent.ExtendedCompositeComponent.classConfigurableLifecycleAutomatonImpl<CTX>This class implements aConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton.Methods in org.refcodes.component that return ConfigurableLifecycleComponent Modifier and Type Method Description protected ConfigurableLifecycleComponent<CTX>ConfigurableLifecycleAutomatonImpl. getLifecycleComponent()Provides access to theLifecycleComponentinstance.Constructors in org.refcodes.component with parameters of type ConfigurableLifecycleComponent Constructor Description ConfigurableLifecycleAutomatonImpl(ConfigurableLifecycleComponent<CTX> aLifeConfigurableCycleComponent)This constructor uses aLifecycleStatusfor wrapping it inside theConfigurableLifecycleAutomatonImpl, making sure of obeying and guarding the correctLifecycleStatus's order ofLifecycleStatusstates for you.
-