Uses of Interface
org.refcodes.component.ConnectionComponent
-
Uses of ConnectionComponent in org.refcodes.component
Subinterfaces of ConnectionComponent in org.refcodes.componentModifier and TypeInterfaceDescriptionstatic interfaceTheCompositeComponent.ExtendedCompositeComponentprovides extended functionality to theCompositeComponent's functionality by including extendedOpenablefunctionality (ConnectionOpenable) and extendsInitializablefunctionality (Configurable).static interfaceA system implementing theConnectionComponent.ConnectionAutomatoninterface supports managingConnectionComponentinstances and takes care that the open/close statuses are invoked in the correct order by throwing according exceptions in case the open/close-cycle is invoked in the wrong order.static interfaceConnectionComponent.ConnectionComponentBuilder<CON,B extends ConnectionComponent.ConnectionComponentBuilder<CON, B>> Similar to theConnectionComponentwith additional according builder methods.Classes in org.refcodes.component that implement ConnectionComponentModifier and TypeClassDescriptionstatic classCompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX, CON> TheCompositeComponentImpl.ExtendedCompositeComponentImplis an implementation of theCompositeComponent.ExtendedCompositeComponent.classThis class implements aConnectionComponent.ConnectionAutomaton.Fields in org.refcodes.component declared as ConnectionComponentModifier and TypeFieldDescriptionprotected ConnectionComponent<CON>ConnectionAutomatonImpl._connectionComponentConstructors in org.refcodes.component with parameters of type ConnectionComponentModifierConstructorDescriptionConnectionAutomatonImpl(ConnectionComponent<CON> aConnectionComponent) This constructor uses aLifecycleStatusfor wrapping it inside theConnectionAutomatonImpl, making sure of obeying and guarding the correctLifecycleStatus's order ofLifecycleStatusstates for you.