Uses of Interface
org.refcodes.component.ConnectionOpenable
-
Uses of ConnectionOpenable in org.refcodes.component
Subinterfaces of ConnectionOpenable in org.refcodes.componentModifier and TypeInterfaceDescriptionstatic interfaceTheCompositeComponent.ExtendedCompositeComponentprovides extended functionality to theCompositeComponent's functionality by including extendedOpenablefunctionality (ConnectionOpenable) and extendsInitializablefunctionality (Configurable).interfaceConnectionComponent<CON>A component implementing theConnectionComponentinterface supports a connection.static interfaceA system implementing theConnectionComponent.ConnectionAutomatoninterface supports managingConnectionComponentinstances and takes care that the open/close statuses are invoked in the correct order by throwing according exceptions in case the open/close-cycle is invoked in the wrong order.static interfaceConnectionComponent.ConnectionComponentBuilder<CON,B extends ConnectionComponent.ConnectionComponentBuilder<CON, B>> Similar to theConnectionComponentwith additional according builder methods.static interfaceTheConnectionOpenable.ConnectionOpenAutomatoninterface defines those methods related to the opening of connection(s) life-cycle.Classes in org.refcodes.component that implement ConnectionOpenableModifier and TypeClassDescriptionstatic classCompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX, CON> TheCompositeComponentImpl.ExtendedCompositeComponentImplis an implementation of theCompositeComponent.ExtendedCompositeComponent.classThis class implements aConnectionComponent.ConnectionAutomaton.