Uses of Enum Class
org.refcodes.component.ConnectionRequest
-
Uses of ConnectionRequest in org.refcodes.component
Subclasses with type arguments of type ConnectionRequest in org.refcodes.componentModifier and TypeClassDescriptionenumAn enumeration describing the connection requests.Methods in org.refcodes.component that return ConnectionRequestModifier and TypeMethodDescriptionstatic ConnectionRequestReturns the enum constant of this class with the specified name.static ConnectionRequest[]ConnectionRequest.values()Returns an array containing the constants of this enum class, in the order they are declared.