Uses of Class
org.refcodes.component.ConnectionStatus
-
-
Uses of ConnectionStatus in org.refcodes.component
Methods in org.refcodes.component that return ConnectionStatus Modifier and Type Method Description ConnectionStatusAbstractConnectableAutomaton. getConnectionStatus()Retrieves theConnectionStatusproperty from the property.ConnectionStatusConnectionAutomatonImpl. getConnectionStatus()Retrieves theConnectionStatusproperty from the property.ConnectionStatusConnectionStatusAccessor. getConnectionStatus()Retrieves theConnectionStatusproperty from the property.ConnectionStatusConnectionStatusHandle. getConnectionStatus(H aHandle)Retrieves theConnectionStatusrelated to the given handle.ConnectionStatusLinkAutomatonImpl. getConnectionStatus()Retrieves theConnectionStatusproperty from the property.default ConnectionStatusConnectionStatusAccessor.ConnectionStatusProperty. letConnectionStatus(ConnectionStatus aConnectionStatus)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenConnectionStatus(setter) as ofConnectionStatusAccessor.ConnectionStatusMutator.setConnectionStatus(ConnectionStatus)and returns the very same value (getter).static ConnectionStatusConnectionStatus. valueOf(String name)Returns the enum constant of this type with the specified name.static ConnectionStatus[]ConnectionStatus. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.component with parameters of type ConnectionStatus Modifier and Type Method Description default ConnectionStatusConnectionStatusAccessor.ConnectionStatusProperty. letConnectionStatus(ConnectionStatus aConnectionStatus)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenConnectionStatus(setter) as ofConnectionStatusAccessor.ConnectionStatusMutator.setConnectionStatus(ConnectionStatus)and returns the very same value (getter).protected voidAbstractConnectableAutomaton. setConnectionStatus(ConnectionStatus aConnectionStatus)Sets theConnectionStatusproperty for the property.voidConnectionStatusAccessor.ConnectionStatusMutator. setConnectionStatus(ConnectionStatus aConnectionStatus)Sets theConnectionStatusproperty for the property.
-