Uses of Interface
org.refcodes.component.DestroyableHandle
-
-
Uses of DestroyableHandle in org.refcodes.component
Subinterfaces of DestroyableHandle in org.refcodes.component Modifier and Type Interface Description interfaceCompositeComponentHandle<H,REF>Similar to theCompositeComponent, theCompositeComponentHandleprovides all the defined handle based functionality, implementing classes provide the means to invoke those methods in case them are supported by the referenced components.interfaceConfigurableLifecycleComponentHandle<H,CTX>TheConfigurableLifecycleComponentHandlemanages variousLifecycleStatusstates forConfigurableLifecycleComponentinstances each related to a handle.static interfaceConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H,CTX>TheConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.static interfaceDestroyableHandle.DestroyAutomatonHandle<H>TheDestroyableHandle.DestroyAutomatonHandleinterface defines those methods related to the handle based destroy life-cycle.interfaceLifecycleComponentHandle<H>TheLifecycleComponentHandlemanages variousLifecycleStatusstates forLifecycleComponentinstances each related to a handle.static interfaceLifecycleComponentHandle.LifecycleAutomatonHandle<H>TheLifecycleComponentHandle.LifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.
-