Uses of Enum Class
org.refcodes.component.ExecutionStatus
-
Uses of ExecutionStatus in org.refcodes.component
Subclasses with type arguments of type ExecutionStatus in org.refcodes.componentMethods in org.refcodes.component that return ExecutionStatusModifier and TypeMethodDescriptionstatic ExecutionStatusReturns the enum constant of this class with the specified name.static ExecutionStatus[]ExecutionStatus.values()Returns an array containing the constants of this enum class, in the order they are declared.