Uses of Interface
org.refcodes.component.Initializable.InitializeAutomaton
-
-
Uses of Initializable.InitializeAutomaton in org.refcodes.component
Subinterfaces of Initializable.InitializeAutomaton in org.refcodes.component Modifier and Type Interface Description static interfaceLifecycleComponent.LifecycleAutomatonA system implementing theLifecycleComponent.LifecycleAutomatoninterface supports managingLifecycleComponentinstances and takes care that the life-cycle stages are invoked in the correct order by throwing according exceptions in case the life-cycle is invoked in the wrong order.Classes in org.refcodes.component that implement Initializable.InitializeAutomaton Modifier and Type Class Description classLifecycleAutomatonImplThis class implements aLifecycleComponent.LifecycleAutomaton.static classLifecycleAutomatonImpl.ManualLifecycleAutomatonImplOpens the otherwise protectedLifecycleAutomatonImpl.ManualLifecycleAutomatonImpl.setLifecycleStatus(LifecycleStatus)to be public in order to force any lifecycle status to be set.
-