Uses of Interface
org.refcodes.component.InitializableHandle.InitializeAutomatonHandle
-
Uses of InitializableHandle.InitializeAutomatonHandle in org.refcodes.component
Subinterfaces of InitializableHandle.InitializeAutomatonHandle in org.refcodes.componentModifier and TypeInterfaceDescriptioninterfaceCompositeComponentHandle<H,REF> Similar to theCompositeComponent, theCompositeComponentHandleprovides all the defined handle based functionality, implementing classes provide the means to invoke those methods in case them are supported by the referenced components.static interfaceTheLifecycleComponentHandle.LifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.