Uses of Class
org.refcodes.component.LifeCycleRequest
-
Uses of LifeCycleRequest in org.refcodes.component
Methods in org.refcodes.component that return LifeCycleRequest Modifier and Type Method Description LifeCycleRequestLifeCycleRequestAccessor. getLifeCycleRequest()Retrieves theLifeCycleRequestproperty from the property.default LifeCycleRequestLifeCycleRequestAccessor.LifeCycleRequestProperty. letLifeCycleRequest(LifeCycleRequest aLifeCycleRequest)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLifeCycleRequest(setter) as ofLifeCycleRequestAccessor.LifeCycleRequestMutator.setLifeCycleRequest(LifeCycleRequest)and returns the very same value (getter).static LifeCycleRequestLifeCycleRequest. valueOf(String name)Returns the enum constant of this type with the specified name.static LifeCycleRequest[]LifeCycleRequest. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.component with parameters of type LifeCycleRequest Modifier and Type Method Description default LifeCycleRequestLifeCycleRequestAccessor.LifeCycleRequestProperty. letLifeCycleRequest(LifeCycleRequest aLifeCycleRequest)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLifeCycleRequest(setter) as ofLifeCycleRequestAccessor.LifeCycleRequestMutator.setLifeCycleRequest(LifeCycleRequest)and returns the very same value (getter).voidLifeCycleRequestAccessor.LifeCycleRequestMutator. setLifeCycleRequest(LifeCycleRequest aLifeCycleRequest)Sets theLifeCycleRequestproperty for the property.