Uses of Interface
org.refcodes.component.LifecycleComponent
-
Uses of LifecycleComponent in org.refcodes.component
Subinterfaces of LifecycleComponent in org.refcodes.componentModifier and TypeInterfaceDescriptioninterfaceAny composite implementation of the refcodes frameworks should implement thisCompositeComponentinterface so that any therein containedComponentinstances' state change methods are supported by theCompositeComponentas well and forwarded to theComponentcontained in theCompositeComponentinstance.static interfaceTheCompositeComponent.ExtendedCompositeComponentprovides extended functionality to theCompositeComponent's functionality by including extendedOpenablefunctionality (ConnectionOpenable) and extendsInitializablefunctionality (Configurable).static interfaceA system implementing theLifecycleComponent.LifecycleAutomatoninterface supports managingLifecycleComponentinstances and takes care that the life-cycle stages are invoked in the correct order by throwing according exceptions in case the life-cycle is invoked in the wrong order.static interfaceSame as theLifecycleComponentthough without the need to try-catch any exceptions on the various life-cycle stages.Classes in org.refcodes.component that implement LifecycleComponentModifier and TypeClassDescriptionclassCompositeComponentImpl<C extends Component>TheCompositeComponentImplis an implementation of theCompositeComponent.static classCompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX, CON> TheCompositeComponentImpl.ExtendedCompositeComponentImplis an implementation of theCompositeComponent.ExtendedCompositeComponent.classThis class implements aLifecycleComponent.LifecycleAutomaton.static classOpens the otherwise protectedLifecycleAutomatonImpl.ManualLifecycleAutomatonImpl.setLifecycleStatus(LifecycleStatus)to be public in order to force any lifecycle status to be set.Methods in org.refcodes.component that return LifecycleComponentModifier and TypeMethodDescriptionprotected LifecycleComponentLifecycleAutomatonImpl.getLifecycleComponent()Provides access to theLifecycleComponentinstance.Constructors in org.refcodes.component with parameters of type LifecycleComponentModifierConstructorDescriptionLifecycleAutomatonImpl(LifecycleComponent aLifecycleComponent) This constructor uses aLifecycleStatusfor wrapping it inside theLifecycleAutomatonImpl, making sure of obeying and guarding the correctLifecycleStatus's order ofLifecycleStatusstates for you.ManualLifecycleAutomatonImpl(LifecycleComponent aLifecycleComponent) This constructor uses aLifecycleAutomatonImpl.ManualLifecycleAutomatonImplfor wrapping it inside theLifecycleAutomatonImpl, making sure of obeying and guarding the correctLifecycleStatus's order ofLifecycleStatusstates for you.