Uses of Class
org.refcodes.component.LifecycleRequest
-
-
Uses of LifecycleRequest in org.refcodes.component
Methods in org.refcodes.component that return LifecycleRequest Modifier and Type Method Description LifecycleRequestLifecycleRequestAccessor. getLifecycleRequest()Retrieves theLifecycleRequestproperty from the property.default LifecycleRequestLifecycleRequestAccessor.LifecycleRequestProperty. letLifecycleRequest(LifecycleRequest aLifecycleRequest)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLifecycleRequest(setter) as ofLifecycleRequestAccessor.LifecycleRequestMutator.setLifecycleRequest(LifecycleRequest)and returns the very same value (getter).static LifecycleRequestLifecycleRequest. valueOf(String name)Returns the enum constant of this type with the specified name.static LifecycleRequest[]LifecycleRequest. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.component with parameters of type LifecycleRequest Modifier and Type Method Description default LifecycleRequestLifecycleRequestAccessor.LifecycleRequestProperty. letLifecycleRequest(LifecycleRequest aLifecycleRequest)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLifecycleRequest(setter) as ofLifecycleRequestAccessor.LifecycleRequestMutator.setLifecycleRequest(LifecycleRequest)and returns the very same value (getter).voidLifecycleRequestAccessor.LifecycleRequestMutator. setLifecycleRequest(LifecycleRequest aLifecycleRequest)Sets theLifecycleRequestproperty for the property.
-