Uses of Interface
org.refcodes.component.LifecycleStatusHandle
-
Uses of LifecycleStatusHandle in org.refcodes.component
Subinterfaces of LifecycleStatusHandle in org.refcodes.componentModifier and TypeInterfaceDescriptioninterfaceCompositeComponentHandle<H,REF> Similar to theCompositeComponent, theCompositeComponentHandleprovides all the defined handle based functionality, implementing classes provide the means to invoke those methods in case them are supported by the referenced components.static interfaceTheConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.static interfaceTheLifecycleComponentHandle.LifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.