Uses of Interface
org.refcodes.component.LinkComponent
-
Uses of LinkComponent in org.refcodes.component
Subinterfaces of LinkComponent in org.refcodes.componentModifier and TypeInterfaceDescriptioninterfaceAny composite implementation of the refcodes frameworks should implement thisCompositeComponentinterface so that any therein containedComponentinstances' state change methods are supported by theCompositeComponentas well and forwarded to theComponentcontained in theCompositeComponentinstance.static interfaceTheCompositeComponent.ExtendedCompositeComponentprovides extended functionality to theCompositeComponent's functionality by including extendedOpenablefunctionality (ConnectionOpenable) and extendsInitializablefunctionality (Configurable).static interfaceA system implementing theLinkComponent.LinkAutomatoninterface supports managingLinkComponentinstances and takes care that the open/close statuses are invoked in the correct order by throwing according exceptions in case the open/close-cycle is invoked in the wrong order.static interfaceSimilar to theLinkComponentwith additional according builder methods.Classes in org.refcodes.component that implement LinkComponentModifier and TypeClassDescriptionclassTheAbstractDeviceAutomatonimplements the very basicAbstractDeviceAutomatonfunctionality.classCompositeComponentImpl<C extends Component>TheCompositeComponentImplis an implementation of theCompositeComponent.static classCompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX, CON> TheCompositeComponentImpl.ExtendedCompositeComponentImplis an implementation of theCompositeComponent.ExtendedCompositeComponent.classThis class implements aLifecycleComponent.LifecycleAutomaton.Fields in org.refcodes.component declared as LinkComponentConstructors in org.refcodes.component with parameters of type LinkComponentModifierConstructorDescriptionLinkAutomatonImpl(LinkComponent aConnectionComponent) This constructor uses aLifecycleStatusfor wrapping it inside theLinkAutomatonImpl, making sure of obeying and guarding the correctLifecycleStatus's order ofLifecycleStatusstates for you.