Uses of Interface
org.refcodes.component.Openable
-
Uses of Openable in org.refcodes.component
Subinterfaces of Openable in org.refcodes.componentModifier and TypeInterfaceDescriptioninterfaceAny composite implementation of the refcodes frameworks should implement thisCompositeComponentinterface so that any therein containedComponentinstances' state change methods are supported by theCompositeComponentas well and forwarded to theComponentcontained in theCompositeComponentinstance.static interfaceTheCompositeComponent.ExtendedCompositeComponentprovides extended functionality to theCompositeComponent's functionality by including extendedOpenablefunctionality (ConnectionOpenable) and extendsInitializablefunctionality (Configurable).interfaceA component implementing theLinkComponentinterface supports establishing a connection (not necessarily a network connection).static interfaceA system implementing theLinkComponent.LinkAutomatoninterface supports managingLinkComponentinstances and takes care that the open/close statuses are invoked in the correct order by throwing according exceptions in case the open/close-cycle is invoked in the wrong order.static interfaceSimilar to theLinkComponentwith additional according builder methods.static interfaceTheOpenable.OpenAutomatoninterface defines those methods related to the opening of connection(s) life-cycle.Classes in org.refcodes.component that implement OpenableModifier and TypeClassDescriptionclassTheAbstractDeviceAutomatonimplements the very basicAbstractDeviceAutomatonfunctionality.classCompositeComponentImpl<C extends Component>TheCompositeComponentImplis an implementation of theCompositeComponent.static classCompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX, CON> TheCompositeComponentImpl.ExtendedCompositeComponentImplis an implementation of theCompositeComponent.ExtendedCompositeComponent.classThis class implements aLifecycleComponent.LifecycleAutomaton.