Uses of Interface
org.refcodes.component.Pausable
-
Uses of Pausable in org.refcodes.component
Subinterfaces of Pausable in org.refcodes.componentModifier and TypeInterfaceDescriptioninterfaceAny composite implementation of the refcodes frameworks should implement thisCompositeComponentinterface so that any therein containedComponentinstances' state change methods are supported by theCompositeComponentas well and forwarded to theComponentcontained in theCompositeComponentinstance.static interfaceTheCompositeComponent.ExtendedCompositeComponentprovides extended functionality to theCompositeComponent's functionality by including extendedOpenablefunctionality (ConnectionOpenable) and extendsInitializablefunctionality (Configurable).interfaceA component implementing theConfigurableLifecycleComponentinterface supports a life-cycle.static interfaceA system implementing theConfigurableLifecycleComponent.ConfigurableLifecycleAutomatoninterface supports managingConfigurableLifecycleComponentinstances and takes care that the open/close statuses are invoked in the correct order by throwing according exceptions in case the open/close-cycle is invoked in the wrong order.interfaceA component implementing theLifecycleComponentinterface supports a life-cycle.static interfaceA system implementing theLifecycleComponent.LifecycleAutomatoninterface supports managingLifecycleComponentinstances and takes care that the life-cycle stages are invoked in the correct order by throwing according exceptions in case the life-cycle is invoked in the wrong order.static interfaceSame as theLifecycleComponentthough without the need to try-catch any exceptions on the various life-cycle stages.static interfaceThePausable.PauseAutomatoninterface defines those methods related to the pause life-cycle.static interfaceSeePausablewithout any checked exception being declared.Classes in org.refcodes.component that implement PausableModifier and TypeClassDescriptionclassCompositeComponentImpl<C extends Component>TheCompositeComponentImplis an implementation of theCompositeComponent.static classCompositeComponentImpl.ExtendedCompositeComponentImpl<C extends Component,CTX, CON> TheCompositeComponentImpl.ExtendedCompositeComponentImplis an implementation of theCompositeComponent.ExtendedCompositeComponent.classThis class implements aConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton.classThis class implements aLifecycleComponent.LifecycleAutomaton.static classOpens the otherwise protectedLifecycleAutomatonImpl.ManualLifecycleAutomatonImpl.setLifecycleStatus(LifecycleStatus)to be public in order to force any lifecycle status to be set.