Uses of Interface
org.refcodes.component.Pausable.PauseAutomaton
-
-
Uses of Pausable.PauseAutomaton in org.refcodes.component
Subinterfaces of Pausable.PauseAutomaton in org.refcodes.component Modifier and Type Interface Description static interfaceConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton<CTX>A system implementing theConfigurableLifecycleComponent.ConfigurableLifecycleAutomatoninterface supports managingConfigurableLifecycleComponentinstances and takes care that the open/close statuses are invoked in the correct order by throwing according exceptions in case the open/close-cycle is invoked in the wrong order.static interfaceLifecycleComponent.LifecycleAutomatonA system implementing theLifecycleComponent.LifecycleAutomatoninterface supports managingLifecycleComponentinstances and takes care that the life-cycle stages are invoked in the correct order by throwing according exceptions in case the life-cycle is invoked in the wrong order.Classes in org.refcodes.component that implement Pausable.PauseAutomaton Modifier and Type Class Description classConfigurableLifecycleAutomatonImpl<CTX>This class implements aConfigurableLifecycleComponent.ConfigurableLifecycleAutomaton.classLifecycleAutomatonImplThis class implements aLifecycleComponent.LifecycleAutomaton.static classLifecycleAutomatonImpl.ManualLifecycleAutomatonImplOpens the otherwise protectedLifecycleAutomatonImpl.ManualLifecycleAutomatonImpl.setLifecycleStatus(LifecycleStatus)to be public in order to force any lifecycle status to be set.
-