Uses of Interface
org.refcodes.component.ResetHandle
-
Uses of ResetHandle in org.refcodes.component
Subinterfaces of ResetHandle in org.refcodes.componentModifier and TypeInterfaceDescriptioninterfaceCompositeComponentHandle<H,REF> Similar to theCompositeComponent, theCompositeComponentHandleprovides all the defined handle based functionality, implementing classes provide the means to invoke those methods in case them are supported by the referenced components.