Uses of Interface
org.refcodes.component.ResumableHandle.ResumeAutomatonHandle
-
-
Uses of ResumableHandle.ResumeAutomatonHandle in org.refcodes.component
Subinterfaces of ResumableHandle.ResumeAutomatonHandle in org.refcodes.component Modifier and Type Interface Description interfaceCompositeComponentHandle<H,REF>Similar to theCompositeComponent, theCompositeComponentHandleprovides all the defined handle based functionality, implementing classes provide the means to invoke those methods in case them are supported by the referenced components.static interfaceConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H,CTX>TheConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.static interfaceLifecycleComponentHandle.LifecycleAutomatonHandle<H>TheLifecycleComponentHandle.LifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.
-