Uses of Interface
org.refcodes.component.StartableHandle
-
-
Uses of StartableHandle in org.refcodes.component
Subinterfaces of StartableHandle in org.refcodes.component Modifier and Type Interface Description interfaceCompositeComponentHandle<H,REF>Similar to theCompositeComponent, theCompositeComponentHandleprovides all the defined handle based functionality, implementing classes provide the means to invoke those methods in case them are supported by the referenced components.interfaceConfigurableLifecycleComponentHandle<H,CTX>TheConfigurableLifecycleComponentHandlemanages variousLifecycleStatusstates forConfigurableLifecycleComponentinstances each related to a handle.static interfaceConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H,CTX>TheConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.interfaceLifecycleComponentHandle<H>TheLifecycleComponentHandlemanages variousLifecycleStatusstates forLifecycleComponentinstances each related to a handle.static interfaceLifecycleComponentHandle.LifecycleAutomatonHandle<H>TheLifecycleComponentHandle.LifecycleAutomatonHandleis an automaton managing variousLifecycleStatusstates forComponentinstances each related to a handle.static interfaceStartableHandle.StartAutomatonHandle<H>TheStartableHandle.StartAutomatonHandleinterface defines those methods related to the handle based start life-cycle.
-