Uses of Class
org.refcodes.component.UnknownHandleRuntimeException

  • Uses of UnknownHandleRuntimeException in org.refcodes.component

    Methods in org.refcodes.component that throw UnknownHandleRuntimeException
    Modifier and Type Method Description
    void CeasableHandle.cease​(H aHandle)
    Ceases the component identified by the given handle.
    void ClosableHandle.close​(H aHandle)
    Closes or pre-closes (flush) the component identified by the given handle.
    void DecomposeableHandle.decompose​(H aHandle)
    Decomposes the component identified by the given handle.
    void DecomposeableHandle.DecomposeAutomatonHandle.decompose​(H aHandle)
    Decomposes the component identified by the given handle.
    void DestroyableHandle.destroy​(H aHandle)
    Destroys the component identified by the given handle.
    void DisposableHandle.dispose​(H aHandle)
    Disposes the component identified by the given handle.
    void FlushHandle.flush​(H aHandle)
    Flushes the component identified by the given handle.
    ConnectionStatus ConnectionStatusHandle.getConnectionStatus​(H aHandle)
    Retrieves the ConnectionStatus related to the given handle.
    LifeCycleStatus LifeCycleStatusHandle.getLifeCycleStatus​(H aHandle)
    Retrieves the LifeCycleStatus related to the given handle.
    float ProgressHandle.getProgress​(H aHandle)
    The progress of a handle can be queried by this method.
    boolean BidirectionalConnectionOpenableHandle.hasBidirectionalConnectionOpenable​(H aHandle)
    Determines whether the handle reference is BidirectionalConnectionOpenable by implementing the BidirectionalConnectionOpenable interface.
    boolean BidirectionalConnectionOpenableHandle.BidirectionalConnectionOpenAutomatonHandle.hasBidirectionalConnectionOpenAutomaton​(H aHandle)
    Determines whether the handle reference is configurable by implementing the ConnectionOpenable.ConnectionOpenAutomaton interface.
    boolean CeasableHandle.hasCeasable​(H aHandle)
    Determines whether the handle reference is ceasable by implementing the Ceasable interface.
    boolean CeasableHandle.CeaseAutomatonHandle.hasCeaseAutomaton​(H aHandle)
    Determines whether the handle reference is ceasable by implementing the Ceasable.CeaseAutomaton interface.
    boolean ClosableHandle.hasClosable​(H aHandle)
    Determines whether the handle reference is closable by implementing the Closable interface.
    boolean ClosableHandle.CloseAutomatonHandle.hasCloseAutomaton​(H aHandle)
    Determines whether the handle reference is closable by implementing the ConnectionOpenable.ConnectionOpenAutomaton interface.
    boolean ConfigurableHandle.hasConfigurable​(H aHandle)
    Determines whether the handle reference is configurable by implementing the Configurable interface.
    boolean ConfigurableHandle.ConfigureAutomatonHandle.hasConfigureAutomaton​(H aHandle)
    Determines whether the handle reference is configurable by implementing the Configurable.ConfigureAutomaton interface.
    boolean ConnectionOpenableHandle.hasConnectionOpenable​(H aHandle)
    Determines whether the handle reference is ConnectionOpenable by implementing the ConnectionOpenable interface.
    boolean ConnectionOpenableHandle.ConnectionOpenAutomatonHandle.hasConnectionOpenAutomaton​(H aHandle)
    Determines whether the handle reference is configurable by implementing the ConnectionOpenable.ConnectionOpenAutomaton interface.
    boolean ConnectionStatusHandle.hasConnectionStatus​(H aHandle)
    Determines whether the handle reference provides a ConnectionStatus by implementing the ConnectionStatusAccessor interface.
    boolean DecomposeableHandle.hasDecomposeable​(H aHandle)
    Determines whether the handle reference is decomposable by implementing the Decomposeable interface.
    boolean DecomposeableHandle.DecomposeAutomatonHandle.hasDecomposeAutomaton​(H aHandle)
    Determines whether the handle reference is decomposable by implementing the Decomposeable.DecomposeAutomaton interface.
    boolean DestroyableHandle.hasDestroyable​(H aHandle)
    Determines whether the handle reference is destroyable by implementing the Destroyable interface.
    boolean DestroyableHandle.DestroyAutomatonHandle.hasDestroyAutomaton​(H aHandle)
    Determines whether the handle reference is destroyable by implementing the Destroyable.DestroyAutomaton interface.
    boolean DisposableHandle.hasDisposable​(H aHandle)
    Determines whether the handle reference is disposable by implementing the Disposable.Disposedable interface.
    boolean DisposableHandle.DisposeAutomatonHandle.hasDisposeAutomaton​(H aHandle)
    Determines whether the handle reference is disposable by implementing the DisposeAutomaton interface.
    boolean FlushHandle.hasFlush​(H aHandle)
    Determines whether the handle reference provides flushting by implementing the Flushable interface.
    boolean InitializableHandle.hasInitalizable​(H aHandle)
    Determines whether the handle reference is initializeable by implementing the Initializable interface.
    boolean InitializableHandle.InitializeAutomatonHandle.hasInitializeAutomaton​(H aHandle)
    Determines whether the handle reference is initalizable by implementing the Initializable.InitializeAutomaton interface.
    boolean LifeCycleStatusHandle.hasLifeCycleStatus​(H aHandle)
    Determines whether the handle reference provides a LifeCycleStatus by implementing the LifeCycleStatusAccessor interface.
    boolean OpenableHandle.hasOpenable​(H aHandle)
    Determines whether the handle reference is openable by implementing the Openable interface.
    boolean OpenableHandle.OpenAutomatonHandle.hasOpenAutomaton​(H aHandle)
    Determines whether the handle reference is openable by implementing the ConnectionOpenable.ConnectionOpenAutomaton interface.
    boolean PausableHandle.hasPausable​(H aHandle)
    Determines whether the handle reference is pausable by implementing the Pausable interface.
    boolean PausableHandle.PauseAutomatonHandle.hasPauseAutomaton​(H aHandle)
    Determines whether the handle reference is pausable by implementing the Pausable.PauseAutomaton interface.
    boolean ProgressHandle.hasProgress​(H aHandle)
    Determines whether the handle reference provides a progress by implementing the ProgressAccessor interface.
    boolean ReloadHandle.hasReload​(H aHandle)
    Determines whether the handle reference provides reloading by implementing the Reloadable interface.
    boolean ResetHandle.hasReset​(H aHandle)
    Determines whether the handle reference provides resetting by implementing the Resetable interface.
    boolean ResumableHandle.hasResumable​(H aHandle)
    Determines whether the handle reference is resumable by implementing the Resumable interface.
    boolean ResumableHandle.ResumeAutomatonHandle.hasResumeAutomaton​(H aHandle)
    Determines whether the handle reference is resumable by implementing the Resumable.ResumeAutomaton interface.
    boolean StartableHandle.hasStartable​(H aHandle)
    Determines whether the handle reference is startable by implementing the Startable interface.
    boolean StartableHandle.StartAutomatonHandle.hasStartAutomaton​(H aHandle)
    Determines whether the handle reference is startable by implementing the Startable.StartAutomaton interface.
    boolean StoppableHandle.StopAutomatonHandle.hasStopAutomaton​(H aHandle)
    Determines whether the handle reference is stoppable by implementing the Stoppable.StopAutomaton interface.
    boolean StoppableHandle.hasStoppable​(H aHandle)
    Determines whether the handle reference is stoppable by implementing the Stoppable interface.
    void ConfigurableHandle.initialize​(H aHandle, CTX aContext)
    Initialize/configure the component identified by the given handle.
    void InitializableHandle.initialize​(H aHandle)
    Initialize the component identified by the given handle.
    boolean CeasableHandle.CeaseAutomatonHandle.isCeasable​(H aHandle)
    Determines whether the component identified by the given handle may get ceased.
    boolean CeasableHandle.CeaseAutomatonHandle.isCeased​(H aHandle)
    Determines whether the component identified by the given handle is ceased.
    boolean ClosableHandle.CloseAutomatonHandle.isClosable​(H aHandle)
    Determines whether the component identified by the given handle may get closed/disconnected.
    boolean ClosableHandle.CloseAutomatonHandle.isClosed​(H aHandle)
    Determines whether the component (its connection) identified by the given handle is closed (disconnected).
    boolean DecomposeableHandle.DecomposeAutomatonHandle.isDecomposeable​(H aHandle)
    Determines whether the component identified by the given handle may get decomposed.
    boolean DestroyableHandle.DestroyAutomatonHandle.isDestroyable​(H aHandle)
    Determines whether the component identified by the given handle may get destroyed.
    boolean DestroyableHandle.DestroyAutomatonHandle.isDestroyed​(H aHandle)
    Determines whether the component identified by the given handle is destroyed.
    boolean DisposableHandle.DisposeAutomatonHandle.isDisposable​(H aHandle)
    Determines whether the component identified by the given handle may get disposed.
    boolean DisposableHandle.DisposeAutomatonHandle.isDisposed​(H aHandle)
    Determines whether the component identified by the given handle is disposed.
    boolean ConfigurableHandle.ConfigureAutomatonHandle.isInitalizable​(H aHandle, CTX aContext)
    Determines whether the component identified by the given handle may get initialized/configured.
    boolean InitializableHandle.InitializeAutomatonHandle.isInitalizable​(H aHandle)
    Determines whether the component identified by the given handle may get initialized.
    boolean InitializedHandle.isInitzialized​(H aHandle)
    Determines whether the component identified by the given handle is opened.
    boolean BidirectionalConnectionOpenableHandle.BidirectionalConnectionOpenAutomatonHandle.isOpenable​(H aHandle, INPUT aInputConnection, OUTPUT aOutputConnection)
    Determines whether the component identified by the given handle may get opened/connected.
    boolean ConnectionOpenableHandle.ConnectionOpenAutomatonHandle.isOpenable​(H aHandle, CON aConnection)
    Determines whether the component identified by the given handle may get opened/connected.
    boolean OpenableHandle.OpenAutomatonHandle.isOpenable​(H aHandle)
    Determines whether the component identified by the given handle may get opened/connected.
    boolean OpenedHandle.isOpened​(H aHandle)
    Determines whether the component (its connection) identified by the given handle is opened (connected).
    boolean PausableHandle.PauseAutomatonHandle.isPausable​(H aHandle)
    Determines whether the component identified by the given handle may get paused.
    boolean PausableHandle.PauseAutomatonHandle.isPaused​(H aHandle)
    Determines whether the component identified by the given handle is paused.
    boolean ResumableHandle.ResumeAutomatonHandle.isResumable​(H aHandle)
    Determines whether the component identified by the given handle may get resumed.
    boolean RunningHandle.isRunning​(H aHandle)
    Determines whether the component identified by the given handle is running (started or resumed).
    boolean StartableHandle.StartAutomatonHandle.isStartable​(H aHandle)
    Determines whether the component identified by the given handle may get started.
    boolean StoppableHandle.StopAutomatonHandle.isStoppable​(H aHandle)
    Determines whether the component identified by the given handle may get stopped.
    boolean StoppableHandle.StopAutomatonHandle.isStopped​(H aHandle)
    Determines whether the component identified by the given handle is stopped.
    REF HandleLookup.lookupHandle​(H aHandle)
    Gets the object associated to a given handle.
    void BidirectionalConnectionOpenableHandle.open​(H aHandle, INPUT aInputConnection, OUTPUT aOutputConnection)
    Open/connect the component identified by the given handle.
    void ConnectionOpenableHandle.open​(H aHandle, CON aConnection)
    Open/connect the component identified by the given handle.
    void OpenableHandle.open​(H aHandle)
    Open/connect the component identified by the given handle.
    void PausableHandle.pause​(H aHandle)
    Pauses the component identified by the given handle.
    void ReloadHandle.reload​(H aHandle)
    Reloads the (state of the) component identified by the given handle.
    REF HandleLookup.removeHandle​(H aHandle)
    Gets the descriptor for a given handle.
    void ResetHandle.reset​(H aHandle)
    Resets the component identified by the given handle.
    void ResumableHandle.resume​(H aHandle)
    Resumes the component identified by the given handle.
    void StartableHandle.start​(H aHandle)
    Starts the component identified by the given handle.
    void StoppableHandle.stop​(H aHandle)
    Stops the component identified by the given handle.