Uses of Class
org.refcodes.component.UnsupportedHandleOperationRuntimeException

  • Uses of UnsupportedHandleOperationRuntimeException in org.refcodes.component

    Methods in org.refcodes.component that throw UnsupportedHandleOperationRuntimeException
    Modifier and Type Method Description
    void CeasableHandle.cease​(H aHandle)
    Ceases the component identified by the given handle.
    void ClosableHandle.close​(H aHandle)
    Closes or pre-closes (flush) the component identified by the given handle.
    void DecomposeableHandle.decompose​(H aHandle)
    Decomposes the component identified by the given handle.
    void DecomposeableHandle.DecomposeAutomatonHandle.decompose​(H aHandle)
    Decomposes the component identified by the given handle.
    void DestroyableHandle.destroy​(H aHandle)
    Destroys the component identified by the given handle.
    void DisposableHandle.dispose​(H aHandle)
    Disposes the component identified by the given handle.
    void FlushHandle.flush​(H aHandle)
    Flushes the component identified by the given handle.
    ConnectionStatus ConnectionStatusHandle.getConnectionStatus​(H aHandle)
    Retrieves the ConnectionStatus related to the given handle.
    LifeCycleStatus LifeCycleStatusHandle.getLifeCycleStatus​(H aHandle)
    Retrieves the LifeCycleStatus related to the given handle.
    float ProgressHandle.getProgress​(H aHandle)
    The progress of a handle can be queried by this method.
    void ConfigurableHandle.initialize​(H aHandle, CTX aContext)
    Initialize/configure the component identified by the given handle.
    void InitializableHandle.initialize​(H aHandle)
    Initialize the component identified by the given handle.
    boolean CeasableHandle.CeaseAutomatonHandle.isCeasable​(H aHandle)
    Determines whether the component identified by the given handle may get ceased.
    boolean CeasableHandle.CeaseAutomatonHandle.isCeased​(H aHandle)
    Determines whether the component identified by the given handle is ceased.
    boolean ClosableHandle.CloseAutomatonHandle.isClosable​(H aHandle)
    Determines whether the component identified by the given handle may get closed/disconnected.
    boolean ClosableHandle.CloseAutomatonHandle.isClosed​(H aHandle)
    Determines whether the component (its connection) identified by the given handle is closed (disconnected).
    boolean DecomposeableHandle.DecomposeAutomatonHandle.isDecomposeable​(H aHandle)
    Determines whether the component identified by the given handle may get decomposed.
    boolean DestroyableHandle.DestroyAutomatonHandle.isDestroyable​(H aHandle)
    Determines whether the component identified by the given handle may get destroyed.
    boolean DestroyableHandle.DestroyAutomatonHandle.isDestroyed​(H aHandle)
    Determines whether the component identified by the given handle is destroyed.
    boolean DisposableHandle.DisposeAutomatonHandle.isDisposable​(H aHandle)
    Determines whether the component identified by the given handle may get disposed.
    boolean DisposableHandle.DisposeAutomatonHandle.isDisposed​(H aHandle)
    Determines whether the component identified by the given handle is disposed.
    boolean ConfigurableHandle.ConfigureAutomatonHandle.isInitalizable​(H aHandle, CTX aContext)
    Determines whether the component identified by the given handle may get initialized/configured.
    boolean InitializableHandle.InitializeAutomatonHandle.isInitalizable​(H aHandle)
    Determines whether the component identified by the given handle may get initialized.
    boolean InitializedHandle.isInitzialized​(H aHandle)
    Determines whether the component identified by the given handle is opened.
    boolean BidirectionalConnectionOpenableHandle.BidirectionalConnectionOpenAutomatonHandle.isOpenable​(H aHandle, INPUT aInputConnection, OUTPUT aOutputConnection)
    Determines whether the component identified by the given handle may get opened/connected.
    boolean ConnectionOpenableHandle.ConnectionOpenAutomatonHandle.isOpenable​(H aHandle, CON aConnection)
    Determines whether the component identified by the given handle may get opened/connected.
    boolean OpenableHandle.OpenAutomatonHandle.isOpenable​(H aHandle)
    Determines whether the component identified by the given handle may get opened/connected.
    boolean OpenedHandle.isOpened​(H aHandle)
    Determines whether the component (its connection) identified by the given handle is opened (connected).
    boolean PausableHandle.PauseAutomatonHandle.isPausable​(H aHandle)
    Determines whether the component identified by the given handle may get paused.
    boolean PausableHandle.PauseAutomatonHandle.isPaused​(H aHandle)
    Determines whether the component identified by the given handle is paused.
    boolean ResumableHandle.ResumeAutomatonHandle.isResumable​(H aHandle)
    Determines whether the component identified by the given handle may get resumed.
    boolean RunningHandle.isRunning​(H aHandle)
    Determines whether the component identified by the given handle is running (started or resumed).
    boolean StartableHandle.StartAutomatonHandle.isStartable​(H aHandle)
    Determines whether the component identified by the given handle may get started.
    boolean StoppableHandle.StopAutomatonHandle.isStoppable​(H aHandle)
    Determines whether the component identified by the given handle may get stopped.
    boolean StoppableHandle.StopAutomatonHandle.isStopped​(H aHandle)
    Determines whether the component identified by the given handle is stopped.
    void BidirectionalConnectionOpenableHandle.open​(H aHandle, INPUT aInputConnection, OUTPUT aOutputConnection)
    Open/connect the component identified by the given handle.
    void ConnectionOpenableHandle.open​(H aHandle, CON aConnection)
    Open/connect the component identified by the given handle.
    void OpenableHandle.open​(H aHandle)
    Open/connect the component identified by the given handle.
    void PausableHandle.pause​(H aHandle)
    Pauses the component identified by the given handle.
    void ReloadHandle.reload​(H aHandle)
    Reloads the (state of the) component identified by the given handle.
    void ResetHandle.reset​(H aHandle)
    Resets the component identified by the given handle.
    void ResumableHandle.resume​(H aHandle)
    Resumes the component identified by the given handle.
    void StartableHandle.start​(H aHandle)
    Starts the component identified by the given handle.
    void StoppableHandle.stop​(H aHandle)
    Stops the component identified by the given handle.