Class AbstractComponentComposite<C extends Component>

java.lang.Object
org.refcodes.component.AbstractComponentComposite<C>
Type Parameters:
C - The type of the Component supported by the AbstractComponentComposite.
All Implemented Interfaces:
Flushable, Closable, ComponentComposite, Decomposable, Destroyable, Flushable, Initializable, LifecycleComponent, LinkComponent, Openable, Pausable, Resumable, Startable, Stoppable, org.refcodes.mixin.Disposable, org.refcodes.mixin.Resetable
Direct Known Subclasses:
AbstractComponentComposite.ExtendedCompositeComponentImpl

public abstract class AbstractComponentComposite<C extends Component> extends Object implements ComponentComposite
The AbstractComponentComposite is an implementation of the ComponentComposite. To make sure that the state change requests you require are supported by the managed Component instances, specify the according type C as generic type argument.