Class AbstractComponentComposite.ExtendedCompositeComponentImpl<C extends Component,CTX,CON>

java.lang.Object
org.refcodes.component.AbstractComponentComposite<C>
org.refcodes.component.AbstractComponentComposite.ExtendedCompositeComponentImpl<C,CTX,CON>
Type Parameters:
C - The type of the Component supported by the AbstractComponentComposite.ExtendedCompositeComponentImpl.
CTX - the generic type
CON - the generic type
All Implemented Interfaces:
Flushable, Closable, ComponentComposite, ComponentComposite.ExtendedComponentComposite<CTX,CON>, Configurable<CTX>, ConfigurableLifecycleComponent<CTX>, ConnectionComponent<CON>, ConnectionOpenable<CON>, Decomposable, Destroyable, Flushable, Initializable, LifecycleComponent, LinkComponent, Openable, Pausable, Resumable, Startable, Stoppable, org.refcodes.mixin.Disposable, org.refcodes.mixin.Resetable
Enclosing class:
AbstractComponentComposite<C extends Component>

public static class AbstractComponentComposite.ExtendedCompositeComponentImpl<C extends Component,CTX,CON> extends AbstractComponentComposite<C> implements ComponentComposite.ExtendedComponentComposite<CTX,CON>
The AbstractComponentComposite.ExtendedCompositeComponentImpl is an implementation of the ComponentComposite.ExtendedComponentComposite. To make sure that the state change requests you require are supported by the managed Component instances, specify the according type C as generic type argument.