Interface CeasableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CeasableHandle.CeaseAutomatonHandle<H>

public interface CeasableHandle<H>
The CeasableHandle interface defines those methods related to the handle based cease life-cycle.

The handle reference requires the Ceasable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  CeasableHandle.CeaseAutomatonHandle<H>
    The CeasableHandle.CeaseAutomatonHandle interface defines those methods related to the handle based cease life-cycle.
  • Method Summary

    Modifier and Type Method Description
    void cease​(H aHandle)
    Ceases the component identified by the given handle.
    boolean hasCeasable​(H aHandle)
    Determines whether the handle reference is ceasable by implementing the Ceasable interface.