- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
CeasableHandle.CeaseAutomatonHandle<H>
public interface CeasableHandle<H>
The
CeasableHandle interface defines those methods related to the
handle based cease life-cycle.
The handle reference requires the Ceasable interface to be
implemented.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceCeasableHandle.CeaseAutomatonHandle<H>TheCeasableHandle.CeaseAutomatonHandleinterface defines those methods related to the handle based cease life-cycle. -
Method Summary
Modifier and Type Method Description voidcease(H aHandle)Ceases the component identified by the given handle.booleanhasCeasable(H aHandle)Determines whether the handle reference is ceasable by implementing theCeasableinterface.
-
Method Details
-
hasCeasable
Determines whether the handle reference is ceasable by implementing theCeasableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleRuntimeException- in case the handle is unknown.
-
cease
void cease(H aHandle) throws CeaseException, UnknownHandleRuntimeException, UnsupportedHandleOperationRuntimeException, IllegalHandleStateChangeRuntimeExceptionCeases the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
CeaseException- in case ceasing fails.UnknownHandleRuntimeException- in case the given handle is unknown.UnsupportedHandleOperationRuntimeException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeRuntimeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-