Interface ClosableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
ClosableHandle.CloseAutomatonHandle<H>, ConnectionComponentHandle<H,​CON>, ConnectionComponentHandle.ConnectionAutomatonHandle<H,​CON>, LinkComponentHandle<H>, LinkComponentHandle.LinkAutomatonHandle<H>

public interface ClosableHandle<H>
The ClosableHandle interface defines those methods related to the handle based close life-cycle.

The handle reference requires the Closable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  ClosableHandle.CloseAutomatonHandle<H>
    The ClosableHandle.CloseAutomatonHandle interface defines those methods related to the handle based close life-cycle.
  • Method Summary

    Modifier and Type Method Description
    void close​(H aHandle)
    Closes or pre-closes (flush) the component identified by the given handle.
    default void closeUnchecked​(H aHandle)
    Closes the component by calling close(Object) without you to require catching an IOException.
    boolean hasClosable​(H aHandle)
    Determines whether the handle reference is closable by implementing the Closable interface.