Interface Configurable<CTX>

Type Parameters:
CTX - the context used to initialize the implementing instance.
All Known Subinterfaces:
CompositeComponent.ExtendedCompositeComponent<CTX,​CON>, Configurable.ConfigureAutomaton<CTX>, ConfigurableComponent<CTX>, ConfigurableLifeCycleComponent<CTX>, ConfigurableLifeCycleComponent.ConfigurableLifeCycleAutomaton<CTX>
All Known Implementing Classes:
CompositeComponentImpl.ExtendedCompositeComponentImpl, ConfigurableLifeCycleAutomatonImpl

public interface Configurable<CTX>
This mixin might be implemented by a component in order to provide initialize facilities wit a configuration provided via initialize(Object).

In case a no context is to be provided to the initialize(Object) method (as it may have been passed via the constructor), you may use the Initializable interface with its Initializable.initialize() method, which does not require any arguments specifying a context.

  • Method Details

    • initialize

      void initialize​(CTX aContext) throws InitializeException
      Initializes and configures the component.
      Parameters:
      aContext - The context to be passed to the implementing instance.
      Throws:
      InitializeException - Thrown in case initializing fails.
    • initializeUnchecked

      default void initializeUnchecked​(CTX aContext)
      Initializes the component by calling initialize(Object) without you to require catching an ConfigureException.
      Parameters:
      aContext - The context to be passed to the implementing instance.
      Throws:
      org.refcodes.exception.HiddenException - encapsulates the cause and is thrown upon encountering a ConfigureException exception