Interface ConnectionOpenable<CON>

Type Parameters:
CON - The type of the connection to be used.
All Known Subinterfaces:
ComponentComposite.ExtendedComponentComposite<CTX,CON>, ConnectionComponent<CON>, ConnectionComponent.ConnectionAutomaton<CON>, ConnectionComponent.ConnectionComponentBuilder<CON,B>, ConnectionOpenable.ConnectionOpenAutomaton<CON>
All Known Implementing Classes:
AbstractComponentComposite.ExtendedCompositeComponentImpl, ConnectionAutomatonImpl

public interface ConnectionOpenable<CON>
This mixin might be implemented by a component in order to provide opening connection(s) facilities. The semantics of this interface is very similar to that of the Configurable interface. To clarify the context regarding connections, the ConnectionOpenable interface has been introduced.

In case a no connection is to be provided to the open(Object) method (as it may have been passed via the constructor), you may use the Openable interface with its Openable.open() method, which does not require any arguments specifying a connection.