-
- All Superinterfaces:
OpenedAccessor
- All Known Subinterfaces:
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>,ConnectableComponent.ConnectableAutomaton,ConnectionComponent.ConnectionAutomaton<CON>,ConnectionStatusAccessor.ConnectionStatusProperty,LinkComponent.LinkAutomaton
- All Known Implementing Classes:
AbstractConnectableAutomaton,AbstractDeviceAutomaton,ConnectionAutomatonImpl,LinkAutomatonImpl
public interface ConnectionStatusAccessor extends OpenedAccessor
Provides an accessor for aConnectionStatusproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceConnectionStatusAccessor.ConnectionStatusMutatorProvides a mutator for aConnectionStatusproperty.static interfaceConnectionStatusAccessor.ConnectionStatusPropertyProvides aConnectionStatusproperty.-
Nested classes/interfaces inherited from interface org.refcodes.component.OpenedAccessor
OpenedAccessor.OpenedMutator, OpenedAccessor.OpenedProperty
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description ConnectionStatusgetConnectionStatus()Retrieves theConnectionStatusproperty from the property.default booleanisOpened()Determines whether the connection is ought to be open or not.
-
-
-
Method Detail
-
getConnectionStatus
ConnectionStatus getConnectionStatus()
Retrieves theConnectionStatusproperty from the property. Determines in whichConnectionStatusstatus a component is in.- Returns:
- Returns the
ConnectionStatusproperty stored by the property.
-
isOpened
default boolean isOpened()
Determines whether the connection is ought to be open or not.- Specified by:
isOpenedin interfaceOpenedAccessor- Returns:
- True in case the connection is open, else the connection is
either closed or of a status
ConnectionStatus.NONE.
-
-