Class DestroyException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.component.ComponentRuntimeException
org.refcodes.component.LifecycleException.LifecycleRuntimeException
org.refcodes.component.DestroyException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
Thrown in case destroying a component caused problems. Usually a method
similar to "destroy()" throws such an exception. This is a
RuntimeException as destroying a component should always succeed and
a DestroyException should only be thrown in case of obvious
malfunctioning and the philosophy of "fail early!" without forcing a method
to declare an according checked exception!- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classUnchecked exception with the same semantics as theDestroyException.Nested classes/interfaces inherited from class org.refcodes.component.ComponentRuntimeException
ComponentRuntimeException.ComponentHandleRuntimeExceptionNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionDestroyException(String aMessage) Instantiates the classDestroyException.DestroyException(String aMessage, String aErrorCode) Instantiates the classDestroyException.DestroyException(String aMessage, Throwable aCause) Instantiates the classDestroyException.DestroyException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classDestroyException.DestroyException(Throwable aCause) Instantiates the classDestroyException.DestroyException(Throwable aCause, String aErrorCode) Instantiates the classDestroyException. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractRuntimeException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
DestroyException
Instantiates the classDestroyException.- See Also:
-
DestroyException
Instantiates the classDestroyException.- See Also:
-
DestroyException
Instantiates the classDestroyException.- See Also:
-
DestroyException
-
DestroyException
Instantiates the classDestroyException.- See Also:
-
DestroyException
-