Class DestroyException

java.lang.Object
All Implemented Interfaces:
Serializable, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap

public class DestroyException extends LifecycleException.LifecycleRuntimeException
Thrown in case destroying a component caused problems. Usually a method similar to "destroy()" throws such an exception. This is a RuntimeException as destroying a component should always succeed and a DestroyException should only be thrown in case of obvious malfunctioning and the philosophy of "fail early!" without forcing a method to declare an according checked exception!
See Also: