- All Superinterfaces:
Destroyable
- All Known Subinterfaces:
ConfigurableLifeCycleComponent.ConfigurableLifeCycleAutomaton<CTX>,LifeCycleComponent.LifeCycleAutomaton
- All Known Implementing Classes:
ConfigurableLifeCycleAutomatonImpl,LifeCycleAutomatonImpl,LifeCycleAutomatonImpl.ManualLifeCycleAutomatonImpl
- Enclosing interface:
- Destroyable
public static interface Destroyable.DestroyAutomaton extends Destroyable
The
Destroyable.DestroyAutomaton interface defines those methods related to
the destroy life-cycle.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.component.Destroyable
Destroyable.DestroyAutomaton -
Method Summary
Modifier and Type Method Description booleanisDestroyable()Determines whether the component may get destroyed.booleanisDestroyed()Determines whether the component is destroyed.Methods inherited from interface org.refcodes.component.Destroyable
destroy
-
Method Details
-
isDestroyable
boolean isDestroyable()Determines whether the component may get destroyed.- Returns:
- True if
Destroyable.destroy()is possible.
-
isDestroyed
boolean isDestroyed()Determines whether the component is destroyed. In case of being true, then invoking any of thatComponentinstance's methods (except theDestroyable.destroy()method) must throw anIllegalStateExceptionas by definition a once destroyedComponentis in the state of being destroyed which is irreversible.- Returns:
- True in case of being destroyed, else false.
-