- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
CompositeComponentHandle<H,REF>,ConfigurableLifeCycleComponentHandle<H,CTX>,ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,CTX>,DestroyableHandle.DestroyAutomatonHandle<H>,LifeCycleComponentHandle<H>,LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>
public interface DestroyableHandle<H>
The
DestroyableHandle interface defines those methods related to the
handle based destroy life-cycle.
The handle reference requires the Destroyable interface to be
implemented.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceDestroyableHandle.DestroyAutomatonHandle<H>TheDestroyableHandle.DestroyAutomatonHandleinterface defines those methods related to the handle based destroy life-cycle. -
Method Summary
Modifier and Type Method Description voiddestroy(H aHandle)Destroys the component identified by the given handle.booleanhasDestroyable(H aHandle)Determines whether the handle reference is destroyable by implementing theDestroyableinterface.
-
Method Details
-
hasDestroyable
Determines whether the handle reference is destroyable by implementing theDestroyableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleRuntimeException- in case the handle is unknown.
-
destroy
void destroy(H aHandle) throws UnknownHandleRuntimeException, UnsupportedHandleOperationRuntimeException, IllegalHandleStateChangeRuntimeExceptionDestroys the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
UnknownHandleRuntimeException- in case the given handle is unknown.UnsupportedHandleOperationRuntimeException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeRuntimeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-