Interface DisposableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
DisposableHandle.DisposeAutomatonHandle<H>

public interface DisposableHandle<H>
The DisposableHandle interface defines those methods related to the handle based dispose life-cycle.

The handle reference requires the Disposable.Disposedable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  DisposableHandle.DisposeAutomatonHandle<H>
    The DisposableHandle.DisposeAutomatonHandle interface defines those methods related to the handle based dispose life-cycle.
  • Method Summary

    Modifier and Type Method Description
    void dispose​(H aHandle)
    Disposes the component identified by the given handle.
    boolean hasDisposable​(H aHandle)
    Determines whether the handle reference is disposable by implementing the Disposable.Disposedable interface.