Interface FlushHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>

public interface FlushHandle<H>
The FlushHandle interface defines those methods related to the handle based flush operation.

The handle reference requires the Flushable interface to be implemented.

  • Method Summary

    Modifier and Type Method Description
    void flush​(H aHandle)
    Flushes the component identified by the given handle.
    default void flushUnchecked​(H aHandle)
    Flushes the component by calling flush(Object) without you to require catching a IOException.
    boolean hasFlush​(H aHandle)
    Determines whether the handle reference provides flushting by implementing the Flushable interface.