Interface HandleLookup<H,​REF>

Type Parameters:
H - The type of the handles.
REF - The type of the objects to which the handles reference to.
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>, HandleDirectory<H,​REF>

public interface HandleLookup<H,​REF>
Any system in this framework being able to work with handles provides an implementation of the handle lookup interface. This enables a unified access to the system wide handles.
  • Method Summary

    Modifier and Type Method Description
    boolean hasHandle​(H aHandle)
    Used to test if the given handle is known by an implementing system.
    REF lookupHandle​(H aHandle)
    Gets the object associated to a given handle.
    REF removeHandle​(H aHandle)
    Gets the descriptor for a given handle.
  • Method Details

    • hasHandle

      boolean hasHandle​(H aHandle)
      Used to test if the given handle is known by an implementing system.
      Parameters:
      aHandle - The handle for which to find out if there is any related data.
      Returns:
      True if the handle is known.
    • lookupHandle

      REF lookupHandle​(H aHandle) throws UnknownHandleRuntimeException
      Gets the object associated to a given handle.
      Parameters:
      aHandle - The handle for which to get the related data.
      Returns:
      The object associated to the given handle.
      Throws:
      UnknownHandleRuntimeException - the unknown handle runtime exception
    • removeHandle

      REF removeHandle​(H aHandle) throws UnknownHandleRuntimeException
      Gets the descriptor for a given handle.
      Parameters:
      aHandle - The handle for which to get the descriptor.
      Returns:
      The descriptor for the given handle.
      Throws:
      UnknownHandleRuntimeException - the unknown handle runtime exception