Interface InitializableHandle<H>
- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
ComponentHandleComposite<H,REF>, ConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H, CTX>, InitializableHandle.InitializeAutomatonHandle<H>, LifecycleComponentHandle<H>, LifecycleComponentHandle.LifecycleAutomatonHandle<H>
public interface InitializableHandle<H>
The
InitializableHandle interface defines those methods related to
the handle based initialize life-cycle.
The handle reference requires the Initializable interface to be
implemented.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheInitializableHandle.InitializeAutomatonHandleinterface defines those methods related to the handle based initialize life-cycle. -
Method Summary
Modifier and TypeMethodDescriptionbooleanhasInitalizable(H aHandle) Determines whether the handle reference is initializeable by implementing theInitializableinterface.voidinitialize(H aHandle) Initialize the component identified by the given handle.
-
Method Details
-
hasInitalizable
Determines whether the handle reference is initializeable by implementing theInitializableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleException- in case the handle is unknown.
-
initialize
Initialize the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
InitializeException- in case initializing fails.UnknownHandleException- in case the given handle is unknown.UnsupportedHandleOperationException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-