Interface InitializableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>, ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,​CTX>, InitializableHandle.InitializeAutomatonHandle<H>, LifeCycleComponentHandle<H>, LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>

public interface InitializableHandle<H>
The InitializableHandle interface defines those methods related to the handle based initialize life-cycle.

The handle reference requires the Initializable interface to be implemented.