- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
CompositeComponentHandle<H,REF>,ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,CTX>,InitializableHandle.InitializeAutomatonHandle<H>,LifeCycleComponentHandle<H>,LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>
public interface InitializableHandle<H>
The
InitializableHandle interface defines those methods related to
the handle based initialize life-cycle.
The handle reference requires the Initializable interface to be
implemented.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceInitializableHandle.InitializeAutomatonHandle<H>TheInitializableHandle.InitializeAutomatonHandleinterface defines those methods related to the handle based initialize life-cycle. -
Method Summary
Modifier and Type Method Description booleanhasInitalizable(H aHandle)Determines whether the handle reference is initializeable by implementing theInitializableinterface.voidinitialize(H aHandle)Initialize the component identified by the given handle.default voidinitializeUnchecked(H aHandle)Initialize the component by callinginitialize(Object)without you to require catching anInitializeException.
-
Method Details
-
hasInitalizable
Determines whether the handle reference is initializeable by implementing theInitializableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleRuntimeException- in case the handle is unknown.
-
initialize
void initialize(H aHandle) throws InitializeException, UnknownHandleRuntimeException, UnsupportedHandleOperationRuntimeException, IllegalHandleStateChangeRuntimeExceptionInitialize the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
InitializeException- in case initializing fails.UnknownHandleRuntimeException- in case the given handle is unknown.UnsupportedHandleOperationRuntimeException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeRuntimeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-
initializeUnchecked
Initialize the component by callinginitialize(Object)without you to require catching anInitializeException.- Parameters:
aHandle- The handle identifying the component.- Throws:
org.refcodes.exception.HiddenException- encapsulates the cause and is thrown upon encountering aInitializeExceptionexception
-