Interface OpenableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
LinkComponentHandle<H>, LinkComponentHandle.LinkAutomatonHandle<H>, OpenableHandle.OpenAutomatonHandle<H>

public interface OpenableHandle<H>
The OpenableHandle interface defines those methods related to the handle based open/connect life-cycle.

The handle reference requires the Openable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  OpenableHandle.OpenAutomatonHandle<H>
    The OpenableHandle.OpenAutomatonHandle interface defines those methods related to the handle based open/connect life-cycle.
  • Method Summary

    Modifier and Type Method Description
    boolean hasOpenable​(H aHandle)
    Determines whether the handle reference is openable by implementing the Openable interface.
    void open​(H aHandle)
    Open/connect the component identified by the given handle.
    default void openUnchecked​(H aHandle)
    Opens the component by calling open(Object) without you to require catching an IOException.