Module org.refcodes.component
Package org.refcodes.component
Interface Pausable.PauseBuilder<B extends Pausable.PauseBuilder<B>>
-
Method Summary
Modifier and TypeMethodDescriptiondefault BPauses the component by callingwithPause()without you to require catching anPauseException.Builder method for thePausable.pause()method.
-
Method Details
-
withPause
Builder method for thePausable.pause()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
PauseException- Thrown in case pausing fails.
-
pauseUnchecked
Pauses the component by callingwithPause()without you to require catching anPauseException.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
PauseException.PauseRuntimeException- encapsulates the aCause and is thrown upon encountering aPauseExceptionexception
-