Interface PausableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
ComponentHandleComposite<H,REF>, ConfigurableLifecycleComponentHandle<H,CTX>, ConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H,CTX>, LifecycleComponentHandle<H>, LifecycleComponentHandle.LifecycleAutomatonHandle<H>, PausableHandle.PauseAutomatonHandle<H>

public interface PausableHandle<H>
The PausableHandle interface defines those methods related to the handle based pause life-cycle.

The handle reference requires the Pausable interface to be implemented.