Interface PausableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>, ConfigurableLifeCycleComponentHandle<H,​CTX>, ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,​CTX>, LifeCycleComponentHandle<H>, LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>, PausableHandle.PauseAutomatonHandle<H>

public interface PausableHandle<H>
The PausableHandle interface defines those methods related to the handle based pause life-cycle.

The handle reference requires the Pausable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  PausableHandle.PauseAutomatonHandle<H>
    The PausableHandle.PauseAutomatonHandle interface defines those methods related to the handle based pause life-cycle.
  • Method Summary

    Modifier and Type Method Description
    boolean hasPausable​(H aHandle)
    Determines whether the handle reference is pausable by implementing the Pausable interface.
    void pause​(H aHandle)
    Pauses the component identified by the given handle.
    default void pauseUnchecked​(H aHandle)
    Pauses the component by calling pause(Object) without you to require catching an PauseException.