Interface ReloadHandle<H>

Type Parameters:
H - The type of the handle.

public interface ReloadHandle<H>
The ReloadHandle interface defines those methods related to the handle based reload operation.

The handle reference requires the Reloadable interface to be implemented.

  • Method Summary

    Modifier and Type Method Description
    boolean hasReload​(H aHandle)
    Determines whether the handle reference provides reloading by implementing the Reloadable interface.
    void reload​(H aHandle)
    Reloads the (state of the) component identified by the given handle.
    default void reloadUnchecked​(H aHandle)
    Reloads the (state of the) component by calling reload(Object) without you to require catching a IOException.