Interface ResetHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>

public interface ResetHandle<H>
The ResetHandle interface defines those methods related to the handle based reset operation.

The handle reference requires the Resetable interface to be implemented.

  • Method Summary

    Modifier and Type Method Description
    boolean hasReset​(H aHandle)
    Determines whether the handle reference provides resetting by implementing the Resetable interface.
    void reset​(H aHandle)
    Resets the component identified by the given handle.