Interface ResumableHandle<H>
- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
ComponentHandleComposite<H,REF>, ConfigurableLifecycleComponentHandle<H, CTX>, ConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H, CTX>, LifecycleComponentHandle<H>, LifecycleComponentHandle.LifecycleAutomatonHandle<H>, ResumableHandle.ResumeAutomatonHandle<H>
public interface ResumableHandle<H>
The
ResumableHandle interface defines those methods related to the
handle based resume life-cycle.
The handle reference requires the Resumable interface to be
implemented.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheResumableHandle.ResumeAutomatonHandleinterface defines those methods related to the handle based resume life-cycle. -
Method Summary
Modifier and TypeMethodDescriptionbooleanhasResumable(H aHandle) Determines whether the handle reference is resumable by implementing theResumableinterface.voidResumes the component identified by the given handle.
-
Method Details
-
hasResumable
Determines whether the handle reference is resumable by implementing theResumableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleException- in case the handle is unknown.
-
resume
Resumes the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
ResumeException- in case resuming fails.UnknownHandleException- in case the given handle is unknown.UnsupportedHandleOperationException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-