- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
CompositeComponentHandle<H,REF>,ConfigurableLifeCycleComponentHandle<H,CTX>,ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,CTX>,LifeCycleComponentHandle<H>,LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>,ResumableHandle.ResumeAutomatonHandle<H>
public interface ResumableHandle<H>
The
ResumableHandle interface defines those methods related to the
handle based resume life-cycle.
The handle reference requires the Resumable interface to be
implemented.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceResumableHandle.ResumeAutomatonHandle<H>TheResumableHandle.ResumeAutomatonHandleinterface defines those methods related to the handle based resume life-cycle. -
Method Summary
Modifier and Type Method Description booleanhasResumable(H aHandle)Determines whether the handle reference is resumable by implementing theResumableinterface.voidresume(H aHandle)Resumes the component identified by the given handle.default voidresumeUnchecked(H aHandle)Resumes the component by callingresume(Object)without you to require catching anResumeException.
-
Method Details
-
hasResumable
Determines whether the handle reference is resumable by implementing theResumableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleRuntimeException- in case the handle is unknown.
-
resume
void resume(H aHandle) throws ResumeException, UnknownHandleRuntimeException, UnsupportedHandleOperationRuntimeException, IllegalHandleStateChangeRuntimeExceptionResumes the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
ResumeException- in case resuming fails.UnknownHandleRuntimeException- in case the given handle is unknown.UnsupportedHandleOperationRuntimeException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeRuntimeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-
resumeUnchecked
Resumes the component by callingresume(Object)without you to require catching anResumeException.- Parameters:
aHandle- The handle identifying the component.- Throws:
org.refcodes.exception.HiddenException- encapsulates the cause and is thrown upon encountering aResumeExceptionexception
-