Interface Startable.StartBuilder<B extends Startable.StartBuilder<B>>
-
Method Summary
Modifier and TypeMethodDescriptionBuilder method for theStartable.start()method.default BStarts the component by callingwithStart()without you to require catching anStartException.
-
Method Details
-
withStart
Builder method for theStartable.start()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
StartException- Thrown in case starting fails.
-
withStartUnchecked
Starts the component by callingwithStart()without you to require catching anStartException.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
StartException.StartRuntimeException- encapsulates the aCause and is thrown upon encountering aStartExceptionexception
-