Interface StartableHandle<H>
- Type Parameters:
H- The type of the handle.
- All Known Subinterfaces:
ComponentHandleComposite<H,REF>, ConfigurableLifecycleComponentHandle<H, CTX>, ConfigurableLifecycleComponentHandle.ConfigurableLifecycleAutomatonHandle<H, CTX>, LifecycleComponentHandle<H>, LifecycleComponentHandle.LifecycleAutomatonHandle<H>, StartableHandle.StartAutomatonHandle<H>
public interface StartableHandle<H>
The
StartableHandle interface defines those methods related to the
handle based start life-cycle.
The handle reference requires the Startable interface to be
implemented.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTheStartableHandle.StartAutomatonHandleinterface defines those methods related to the handle based start life-cycle. -
Method Summary
Modifier and TypeMethodDescriptionbooleanhasStartable(H aHandle) Determines whether the handle reference is startable by implementing theStartableinterface.voidStarts the component identified by the given handle.
-
Method Details
-
hasStartable
Determines whether the handle reference is startable by implementing theStartableinterface.- Parameters:
aHandle- The handle to test whether the reference provides the according functionality.- Returns:
- True in case the reference provides the according functionality.
- Throws:
UnknownHandleException- in case the handle is unknown.
-
start
Starts the component identified by the given handle.- Parameters:
aHandle- The handle identifying the component.- Throws:
StartException- in case starting fails.UnknownHandleException- in case the given handle is unknown.UnsupportedHandleOperationException- in case the reference of the handle does not support the requested operation.IllegalHandleStateChangeException- Thrown in case a state change is not possible due to the current state the referenced component is in.
-