Interface StartableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>, ConfigurableLifeCycleComponentHandle<H,​CTX>, ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,​CTX>, LifeCycleComponentHandle<H>, LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>, StartableHandle.StartAutomatonHandle<H>

public interface StartableHandle<H>
The StartableHandle interface defines those methods related to the handle based start life-cycle.

The handle reference requires the Startable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  StartableHandle.StartAutomatonHandle<H>
    The StartableHandle.StartAutomatonHandle interface defines those methods related to the handle based start life-cycle.
  • Method Summary

    Modifier and Type Method Description
    boolean hasStartable​(H aHandle)
    Determines whether the handle reference is startable by implementing the Startable interface.
    void start​(H aHandle)
    Starts the component identified by the given handle.
    default void startUnchecked​(H aHandle)
    Starts the component by calling start(Object) without you to require catching an StartException.