- All Known Subinterfaces:
CompositeComponent,CompositeComponent.ExtendedCompositeComponent<CTX,CON>,ConfigurableLifeCycleComponent<CTX>,ConfigurableLifeCycleComponent.ConfigurableLifeCycleAutomaton<CTX>,LifeCycleComponent,LifeCycleComponent.LifeCycleAutomaton,LifeCycleComponent.UncheckedLifeCycleComponent,Stoppable.StopAutomaton,Stoppable.UncheckedStoppable
- All Known Implementing Classes:
CompositeComponentImpl,CompositeComponentImpl.ExtendedCompositeComponentImpl,ConfigurableLifeCycleAutomatonImpl,LifeCycleAutomatonImpl,LifeCycleAutomatonImpl.ManualLifeCycleAutomatonImpl
public interface Stoppable
This mixin might be implemented by a component in order to provide stop
facilities.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceStoppable.StopAutomatonTheStoppable.StopAutomatoninterface defines those methods related to the stop life-cycle.static interfaceStoppable.StopBuilder<B extends Stoppable.StopBuilder<B>>To enable theStoppablefunctionality to be invoked in a builder chain.static interfaceStoppable.UncheckedStoppableSeeStoppablewithout any checked exception being declared. -
Method Summary
Modifier and Type Method Description voidstop()Stops the component.default voidstopUnchecked()Stops the component by callingstop()without you to require catching anStopException.
-
Method Details
-
stop
Stops the component.- Throws:
StopException- Thrown in case stopping fails.
-
stopUnchecked
default void stopUnchecked()Stops the component by callingstop()without you to require catching anStopException.- Throws:
StopException.StopRuntimeException- encapsulates the cause and is thrown upon encountering aStopExceptionexception
-