Interface Stoppable.StopBuilder<B extends Stoppable.StopBuilder<B>>
- Type Parameters:
B- The instance to be returned on which to apply succeeding builder operations.
- Enclosing interface:
Stoppable
public static interface Stoppable.StopBuilder<B extends Stoppable.StopBuilder<B>>
To enable the
Stoppable functionality to be invoked in a builder
chain.-
Method Summary
-
Method Details
-
withStop
Builder method for theStoppable.stop()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
StopException- Thrown in case stopping fails.
-