Interface Stoppable.StopBuilder<B extends Stoppable.StopBuilder<B>>
-
Method Summary
Modifier and TypeMethodDescriptionwithStop()Builder method for theStoppable.stop()method.default BStops the component by callingwithStop()without you to require catching anStopException.
-
Method Details
-
withStop
Builder method for theStoppable.stop()method.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
StopException- Thrown in case stopping fails.
-
withStopUnchecked
Stops the component by callingwithStop()without you to require catching anStopException.- Returns:
- The instance to be returned on which to apply succeeding builder operations.
- Throws:
StopException.StopRuntimeException- encapsulates the aCause and is thrown upon encountering aStopExceptionexception
-