Interface StoppableHandle<H>

Type Parameters:
H - The type of the handle.
All Known Subinterfaces:
CompositeComponentHandle<H,​REF>, ConfigurableLifeCycleComponentHandle<H,​CTX>, ConfigurableLifeCycleComponentHandle.ConfigurableLifeCycleAutomatonHandle<H,​CTX>, LifeCycleComponentHandle<H>, LifeCycleComponentHandle.LifeCycleAutomatonHandle<H>, StoppableHandle.StopAutomatonHandle<H>

public interface StoppableHandle<H>
The StoppableHandle interface defines those methods related to the handle based stop life-cycle.

The handle reference requires the Stoppable interface to be implemented.

  • Nested Class Summary

    Nested Classes
    Modifier and Type Interface Description
    static interface  StoppableHandle.StopAutomatonHandle<H>
    The StoppableHandle.StopAutomatonHandle interface defines those methods related to the handle based stop life-cycle.
  • Method Summary

    Modifier and Type Method Description
    boolean hasStoppable​(H aHandle)
    Determines whether the handle reference is stoppable by implementing the Stoppable interface.
    void stop​(H aHandle)
    Stops the component identified by the given handle.
    default void stopUnchecked​(H aHandle)
    Stops the component by calling stop(Object) without you to require catching an StopException.