static class |
CeaseException.CeaseRuntimeException |
|
static class |
CloseException.CloseRuntimeException |
|
static class |
ConfigureException.ConfigureRuntimeException |
Thrown in case initializing a component caused problems.
|
static class |
DecomposeException.DecomposeRuntimeException |
|
static class |
DestroyException.DestroyRuntimeException |
|
static class |
DigestException.DigestRuntimeException |
|
static class |
DisposeException.DisposeRuntimeException |
|
class |
HandleTimeoutRuntimeException |
This exception is thrown in case a handle was provided which was unknown to
the invoked component.
|
class |
IllegalHandleStateChangeRuntimeException |
This exception is thrown in case a handle was provided whose reference does
not support a given operation.
|
static class |
InitializeException.InitializeRuntimeException |
Unchecked exception with the same semantics as the IOException.
|
static class |
LifecycleException.LifecycleRuntimeException |
This exception is the base lifecycle exception .
|
static class |
PauseException.PauseRuntimeException |
|
static class |
ResetException.ResetRuntimeException |
|
static class |
ResumeException.ResumeRuntimeException |
|
static class |
StartException.StartRuntimeException |
|
static class |
StopException.StopRuntimeException |
Unchecked exception with the same semantics as the StopException.
|
class |
UnknownHandleRuntimeException |
This exception is thrown in case a handle was provided which was unknown to
the invoked component.
|
class |
UnsupportedHandleOperationRuntimeException |
This exception is thrown in case a handle was provided whose reference does
not support a given operation.
|