Uses of Class
org.refcodes.component.ComponentRuntimeException
-
Uses of ComponentRuntimeException in org.refcodes.component
Subclasses of ComponentRuntimeException in org.refcodes.component Modifier and Type Class Description static classCeaseException.CeaseRuntimeExceptionUnchecked exception with the same semantics as theCeaseException.classHandleTimeoutRuntimeExceptionThis exception is thrown in case a handle was provided which was unknown to the invoked component.classIllegalHandleStateChangeRuntimeExceptionThis exception is thrown in case a handle was provided whose reference does not support a given operation.static classInitializeException.InitializeRuntimeExceptionUnchecked exception with the same semantics as theIOException.static classPauseException.PauseRuntimeExceptionUnchecked exception with the same semantics as thePauseException.static classResumeException.ResumeRuntimeExceptionUnchecked exception with the same semantics as theResumeException.static classStartException.StartRuntimeExceptionUnchecked exception with the same semantics as theStartException.static classStopException.StopRuntimeExceptionUnchecked exception with the same semantics as theStopException.classUnknownHandleRuntimeExceptionThis exception is thrown in case a handle was provided which was unknown to the invoked component.classUnsupportedHandleOperationRuntimeExceptionThis exception is thrown in case a handle was provided whose reference does not support a given operation.