Uses of Enum
org.refcodes.component.ExecutionStatus
-
Uses of ExecutionStatus in org.refcodes.component
Methods in org.refcodes.component that return ExecutionStatusModifier and TypeMethodDescriptionstatic ExecutionStatusReturns the enum constant of this type with the specified name.static ExecutionStatus[]ExecutionStatus.values()Returns an array containing the constants of this enum type, in the order they are declared.